"use strict";

/* Copyright (c) 2015-2017 APDM, Inc.
 *
 * Line plot to show the means for bilateral variability.
 */
define(['d3', 'apdm_plot'], function (d3, ApdmPlot) {
  BilateralVariabilityPlot.prototype = new ApdmPlot();
  /**
   * Class for constructing variability plot with bilateral means
   */

  function BilateralVariabilityPlot() {
    'use strict';

    this._height = 260;
    this._width = 700;
  }
  /**
   * Update the plot.
   * @param {d3.selection} selection The container for the plot
   * with the data to plot associated with it.
   */


  BilateralVariabilityPlot.prototype.update = function (selection) {
    var self = this;
    this._plotData = selection.datum(); // Get our y bounds

    var yMax = 0;
    var yMin = 0;
    [this._plotData.leftMean, this._plotData.rightMean].forEach(function (d) {
      d.map(function (e) {
        e = +e;

        if (e > yMax) {
          yMax = e;
        } else if (e < yMin) {
          yMin = e;
        }

        return e;
      });
    });
    var xMax = this._plotData.leftMean.length;
    var widthNoMargins = this._width - this._margin.left - this._margin.right;
    var heightNoMargins = this._height - this._margin.top - this._margin.bottom;
    this._xScale = d3.scaleLinear().range([0, widthNoMargins]).domain([0, xMax]);
    this._yScale = d3.scaleLinear().range([heightNoMargins, 0]).domain([yMin, yMax]);
    this._xAxis = d3.axisBottom(this._xScale).tickFormat(function (d) {
      return d / 2;
    });
    this._yAxis = d3.axisLeft(this._yScale);
    var line = d3.line().x(function (d, i) {
      return self._xScale(i);
    }).y(function (d) {
      return self._yScale(d);
    });
    var plotSvg = selection.selectAll('svg').data([this._plotData]);
    var plotG = plotSvg.enter().append('svg').append('g');
    plotSvg.attr({
      'width': this._width,
      'height': this._height
    }); // Axis and label containers

    plotG.append('g').attr('class', 'x axis');
    plotG.append('g').attr('class', 'y axis');
    plotG.append('text').attr('class', 'x vis_label');
    plotG.append('text').attr('class', 'y vis_label');
    plotG.append('g').attr('class', 'title vis_label');
    plotG = plotSvg.select('g');
    this.buildAxes(plotG);
    this.determineWidthAndMargins(plotG);
    this.setScaleRanges();
    this.buildAxes(plotG);
    plotG.attr('transform', 'translate(' + this._margin.left + ',' + this._margin.top + ')');
    var leftMean = plotG.selectAll('.variability-left-mean').data([this._plotData.leftMean]).enter().append('g').attr({
      'width': this._width - this._margin.right - this._margin.left,
      'height': this._width - this._margin.top - this._margin.bottom,
      'class': 'variability-left-mean'
    });
    leftMean.append('path').attr('class', 'variability-left-mean-line').attr('d', function (d) {
      return line(d);
    });
    var rightMean = plotG.selectAll('.variability-right-mean').data([this._plotData.rightMean]).enter().append('g').attr({
      'width': this._width - this._margin.right - this._margin.left,
      'height': this._width - this._margin.top - this._margin.bottom,
      'class': 'variability-right-mean'
    });
    rightMean.append('path').attr('class', 'variability-right-mean-line').attr('d', function (d) {
      return line(d);
    });
  };

  return BilateralVariabilityPlot;
});
//# sourceMappingURL=bilateral_variability_plot.js.map
