"use strict";

/* Copyright (c) 2015-2018 APDM, Inc.
 *
 * dialog_in_series.js
 *
 * Extension of the Bootstrap modal dialog.  Designed to smooth
 * transisitons if there are a series of modal dialogs that are
 * opening one after the other.
 */
define(['jquery'], function ($) {
  'use strict';
  /**
   * Create the a Bootstrap modal modal dialog without a backdrop.
   * @param {String} modalId The HTML id of the modal dialog.
   */

  function DialogInSeries(modalId) {
    this.id = modalId;
    this.selection = $('#' + modalId);
    this.selection.modal({
      show: false,
      backdrop: false
    });
    this.selection.on('shown.bs.model', function () {
      console.log('we be showing');
    });
  }

  DialogInSeries.prototype.show = function (showBackdrop) {
    var backdrop;

    if (showBackdrop === true) {
      // Get the backdrop if it exists.
      backdrop = $('.modal-backdrop');

      if (!backdrop.length) {
        backdrop = $('<div class="modal-backdrop fade" id="dialog-in-series"/>');
        backdrop.appendTo(document.body);
      }
    }

    this.selection.modal('show');

    if (backdrop) {
      backdrop.addClass('in');
    }
  };
  /**
   * Hide the modal dialog and, if requested, hide the backdrop
   * and call the callback function if supplied.
   * @param {Boolean} hideBackdrop True if the modal dialog backdrop
   * should be hidden.
   * @param {Function} callback Function to call once modal dialog is
   * completely hidden. Will only be triggered once.
   */


  DialogInSeries.prototype.hide = function (hideBackdrop, callback) {
    // Remove and "on shown" handlers
    this.selection.off('shown.bs.modal'); // Trigger callback once dialog is hidden

    if (callback) {
      this.selection.one('hidden.bs.modal', callback);
    }

    var backdrop = $('.modal-backdrop');
    this.selection.modal('hide');

    if (hideBackdrop === true && backdrop) {
      backdrop.removeClass('in');
      setTimeout(function () {
        backdrop.remove();
      }, 150);
    }
  };
  /**
   * Set a handler to be called when the dialog is shown.
   * @param {Function} callback The function to call when dialog is shown.
   */


  DialogInSeries.prototype.onShown = function (callback) {
    this.selection.off('shown.bs.modal');
    this.selection.on('shown.bs.modal', callback);
  };

  return DialogInSeries;
});
//# sourceMappingURL=dialog_in_series.js.map
