"use strict";

/* Copyright (c) 2016-2018, APDM Inc.
 *
 * hw_error_handler.js
 *
 * Check the server state for an error condition and display the
 * proper error dialog.
 */
define(['jquery', 'server_handler', 'bootstrap-dialog', 'app/ui_state'], function ($, ServerHandler, BootstrapDialog, uiState) {
  'use strict';

  var errorPageOpen = false;
  /**
   * Check the state flag given and determine if it matches any of
   * the known error states.
   * @param {String} serverState The current state of the server.
   * @param {Boolean} isV1 Is the hardware V1.
   * @return {Boolean} Returns true if there was an error.
   */

  function checkForError(serverState, isV1) {
    var html = null;
    var state;
    var postfix = '_v2.html';

    if (isV1) {
      postfix = '_v1.html';
    }

    if (errorPageOpen === false) {
      if (serverState === 'TEST_DOCK_ERROR') {
        html = '/static/html/error.html';
        state = uiState.DOCK_ERROR_PAGE;
      } else if (serverState === 'TEST_CONFIGURATION_ERROR') {
        html = '/static/html/config_error.html';
        state = uiState.ERROR_PAGE;
      } else if (serverState === 'TEST_FILE_ERROR') {
        html = '/static/html/file_error.html';
        state = uiState.FILE_ERROR_PAGE;
      } else if (serverState === 'TEST_CANNNOT_SYNC_RECORD_HEAD') {
        html = '/static/html/sync_error' + postfix;
        state = uiState.ERROR_PAGE;
      } else if (serverState === 'TEST_AP_OPEN_FAILURE') {
        html = '/static/html/ap_open_error' + postfix;
        state = uiState.ERROR_PAGE;
      } else if (serverState === 'TEST_AP_READ_FAILURE') {
        html = '/static/html/ap_read_error' + postfix;
        state = uiState.ERROR_PAGE;
      } else if (serverState === 'TEST_FAILURE') {
        html = '/static/html/unknown_record_error' + postfix;
        state = uiState.ERROR_PAGE;
      } else if (serverState === 'TEST_SYNC_BOX_FAILURE') {
        html = '/static/html/sync_box_failure.html';
        state = uiState.ERROR_PAGE;
      } else if (serverState === 'TEST_UNEXPECTED_OPAL') {
        html = '/static/html/unexpected_opal.html';
        state = uiState.ERROR_PAGE;
      }
    }

    if (html !== null) {
      loadErrorPage(serverState, html, state);
      return true;
    }

    return false;
  }
  /**
   * Display an error page, and then wait until the server is ready
   * to start a new test.
   * @param {String} serverState The server serverState.
   * @param {String} html The HTML to display in error dialog.
   * @param {String} state The UI serverState to pass to server.
   */


  function loadErrorPage(serverState, html, state) {
    errorPageOpen = true; // Determine the buttons and close function for the error dialog

    var errorDialog = new BootstrapDialog({
      id: 'hardware-error-dialog',
      type: BootstrapDialog.TYPE_DANGER,
      title: 'An error has occurred',
      message: $('<div></div>').load(html),
      buttons: [{
        id: 'hardware-error-continue-btn',
        icon: 'iconic iconic-caret-right',
        label: 'Continue',
        cssClass: 'btn-link',
        action: function action(dialog) {
          dialog.close();
        }
      }],
      onhide: function onhide() {
        errorPageOpen = false;
      }
    });
    errorDialog.open();
    ServerHandler.getInstance().postUIState(state);
  }

  return {
    checkForHwError: checkForError
  };
});
//# sourceMappingURL=hw_error_handler.js.map
