"use strict";

/* Copyright (c) 2016-2017 APDM, Inc.
 *
 * Object for holding angle data for a single joint.
 */
define(function () {
  'use strict';

  var ABD_ADD = 'X';
  var FLEX_EXT = 'Y';
  var INT_EXT_ROT = 'Z';
  /**
   * Constructor for the JointAngleData object.
   * @param {String} name The name of this joint.
   * @param {Object} jointData The angle data for the joint.
   */

  function JointAngleData(name, jointData) {
    if (arguments.length < 2) {
      throw 'JointAngleData must be called with initializing data';
    }

    this._name = name;
    this._bilateral = false;
    this._attributes = jointData[ABD_ADD].attributes;
    this._jointData = []; // The stride should be the same for every data set

    var stride = this._attributes.stride[0];
    var startDim = this._attributes.startDims[0];
    jointData[ABD_ADD].data.forEach(function (d, i) {
      var entry = {};
      entry[ABD_ADD] = d;
      entry[FLEX_EXT] = jointData[FLEX_EXT].data[i];
      entry[INT_EXT_ROT] = jointData[INT_EXT_ROT].data[i]; // TODO: Assuming a sample rate of 128 - may not always
      // be the case.

      entry.time = i * stride * 7.8125 + startDim * 7.8125;

      this._jointData.push(entry);
    }, this);
  }
  /**
   * Get the name of the joint.
   * @return {String} The name of the joint.
   */


  JointAngleData.prototype.getName = function () {
    return this._name;
  };
  /**
   * Get the flag that determines if this joint has
   * bilateral data or not.
   * @return {Boolean} True if this joint has 'Left' or 'Right'
   * data.
   */


  JointAngleData.prototype.isBilateral = function () {
    return this._bilateral;
  };
  /**
   * Get the angle data for this joint.
   * @return {Array} Array of angle data objects.
   */


  JointAngleData.prototype.getData = function () {
    return this._jointData;
  };

  JointAngleData.prototype.setData = function (newData) {
    this._jointData = newData;
  };
  /**
   * Get the attributes for the data.
   * @return {Object} Object containing map of attributes for
   * the exported data.
   */


  JointAngleData.prototype.getAttributes = function () {
    return this._attributes;
  };

  return JointAngleData;
});
//# sourceMappingURL=joint_angle_data.js.map
