"use strict";

/**
 * Copyright (c) 2017-2019 APDM, Inc.
 *
 * joint_angle_report.js
 */
define(['jquery', 'd3', 'utils', 'crossroads', 'app/joint_angle_strip_plots', 'app/user_options_handler', 'svg_export', 'app/report_utils', 'bootstrap-dialog', 'app/joint_angle_animation', 'time_based_controller'], function ($, d3, utils, crossroads, JointAngleStripPlots, UserOptionsHandler, svgExport, reportUtils, BootstrapDialog, JointAngleAnimation, TimeBasedController) {
  /**
   * Create the joint angle report instance.
   */
  function jointAngleReport(container, subject, trial, filterType) {
    var _subject = subject;
    var _trial = trial;
    var _filterType = filterType;
    var _container = container;
    var _compareTrials = [];

    var _tbc = TimeBasedController.getInstance();

    var _animationControls = null;
    var _animationControlsId = null;
    var _animation = null;
    var _animationId = null;
    var _video = null;
    var _videoId = null;
    var _stripPlots = null;
    var _stripPlotsId = null;
    /**
     * Update the report.
     */

    function updateReport() {
      clearRegisteredElements();
      $('.report_vis_div').empty();
      $('.empty-on-update').empty();
      generateTitle();
      var text = '';
      var logMsgs = utils.parseTrialLogString(_trial.getLogStr()); // Get the error messages and put them in the dialog.

      if (logMsgs.length > 0) {
        var msgLink = '<a id="trial-log-errors-btn" ' + 'class="trial-log-button text-muted" >' + '<span class="iconic iconic-info"></span></a>';
        var types = logMsgs.map(function (d) {
          return d.type;
        });

        if (types.indexOf('Error') > -1) {
          msgLink = '<a id="trial-log-errors-btn" ' + 'class="trial-log-button text-danger" >' + '<span class="iconic iconic-warning"></span></a>';
        } else if (types.indexOf('Warning') > -1) {
          msgLink = '<a id="trial-log-errors-btn" ' + 'class="trial-log-button text-warning" >' + '<span class="iconic iconic-info"></span></a>';
        }

        text = text + msgLink;
      }

      d3.select('#trial-log-errors-btn').on('click', function () {
        showTrialAnalysisLog(logMsgs);
      });
      var joints = UserOptionsHandler.getInstance().getPlottedJointAngles();
      _stripPlots = new JointAngleStripPlots();
      _stripPlotsId = _tbc.registerElement(_stripPlots);

      _stripPlots.open(_trial, joints, _container); // var animationContainer = _container
      //     .select('#joint-angle-static-animation-container');
      // if (_animation && _animation.clearScene()) {
      //     _animation.clearScene();
      // }
      // _animation =
      //     new JointAngleAnimation(animationContainer, _trial);
      // _animationId = TimeBasedController.getInstance()
      //     .registerElement(_animation);
      // _animation.update();
      // _animationControls =
      //     new AnimationControls(_container.select('#animation-controls'));
      // _animationControlsId = _tbc.registerElement(_animationControls);
      // _animationControls.update();
      // checkForVideo();


      setupPrevNextButtons();
    }
    /**
     * Create the title for the top of the report page.
     */


    function generateTitle() {
      var title = d3.select('#report-title');

      var text = _trial.getTestDisplayName();

      if (trial.getConditionDisplayName() !== text) {
        text = text + ', ' + _trial.getConditionDisplayName();
      }

      text = text + ' - ' + utils.getShortStringFromDate(_trial.getDateObj());
      title.html(text);
    }
    /**
     * Show the analysis log for the trial.
     */


    function showTrialAnalysisLog(logMsgs) {
      BootstrapDialog.show({
        id: 'trial-analysis-log-dialog',
        title: 'Trial Analysis Log',
        message: '<div id="trial-log-container"></div>',
        buttons: [{
          id: 'trial-analysis-log-dialog-close-btn',
          icon: 'iconic iconic-x',
          label: 'Cancel',
          cssClass: 'btn-link',
          action: function action(dialog) {
            dialog.close();
          }
        }],
        onshown: function onshown() {
          d3.select('#trial-analysis-log-dialog').select('#trial-log-container').selectAll('p').data(logMsgs).enter().append('p').text(function (d) {
            return d.message;
          }).each(function (d) {
            var classType = 'lead';

            if (d.type === 'Error') {
              classType = classType + ' text-danger';
            } else if (d.type === 'Warning') {
              classType = classType + ' text-warning';
            }

            d3.select(this).attr('class', classType);
          });
        }
      });
    }
    /**
     * Setup the prev/next buttons in the plot container and the
     * back to subject button.
     */


    function setupPrevNextButtons() {
      var prevBtn = _container.select('#report-prev-trial-button');

      prevBtn.on('click', null);
      prevBtn.on('click', function () {
        _trial = reportUtils.getPreviousOrNextTrial(_subject, _trial, _compareTrials, true);
        updateReport();
      });

      var nextBtn = _container.select('#report-next-trial-button');

      nextBtn.on('click', null);
      nextBtn.on('click', function () {
        _trial = reportUtils.getPreviousOrNextTrial(_subject, _trial, _compareTrials, false);
        updateReport();
      });

      var backBtn = _container.select('#report-back-to-subject-button');

      backBtn.on('click', null);
      backBtn.on('click', function () {
        var objId = _subject.getObjId();

        crossroads.parse('dispatch/subject?id=' + objId.getId() + '&localId=' + objId.getLocalId());
      });
    }
    /**
     * Check to see if a video file exists for the trial.
     */
    // function checkForVideo() {
    //     ServerHandler.getInstance().post(
    //         {
    //             type : ModelProtocol.get_video_metadata,
    //             fileName : _trial.getDataFileName()
    //         },
    //         'json',
    //         function(d) {
    //             if (d.available === true) {
    //                 updateVideo(d.videoPath, d.videoMetadataPath);
    //             }
    //         },
    //         function(d) {
    //             ErrorHandler.showError(d.error().statusText);
    //         });
    // }

    /**
     * Display the video element for the trial.
     * @param {String} videoUrl Path to the video file.
     * @param {String} metaDataPath Path to the workspace video
     * meta data file.
     */
    // function updateVideo(videoUrl, metaDataPath) {
    //     var videoContainer = _container.select('#joint-angle-video-container');
    //     _video = new VideoReportElement(videoContainer, videoUrl,
    //                                     metaDataPath);
    //     _videoId = TimeBasedController.getInstance()
    //         .registerElement(_video);
    //     _video.update();
    // }

    /**
     * Dispose of any existing registered elements the hander may
     * be holding on to.
     */


    function clearRegisteredElements() {
      if (_animation) {
        _animation.dispose();

        _animation = null;
      }

      TimeBasedController.getInstance().unregisterElement(_animationId);

      if (_video) {
        _video.dispose();

        _video = null;
      }

      TimeBasedController.getInstance().unregisterElement(_videoId);

      if (_animationControls) {
        _animationControls.dispose();

        _animationControls = null;
      }

      TimeBasedController.getInstance().unregisterElement(_animationControlsId);

      if (_stripPlots) {
        _stripPlots.dispose();

        _stripPlots = null;
      }

      TimeBasedController.getInstance().unregisterElement(_stripPlotsId);
    }
    /***********************************************************************
     * Public Functions
     ***********************************************************************/


    return {
      /**
       * Get/set the current subject of the report.
       * @param {Subject} subject The subject for this report.
       * @return Current subject if called with no arguments, otherwise this.
       */
      currentSubject: function currentSubject(subject) {
        if (!arguments.length) {
          return _subject;
        }

        _subject = subject;
        return this;
      },

      /**
       * Get/set the current trial for the report.
       * @param {Trial} trial The trial for this report.
       * @return Current trial if called with no arguments, otherwise this.
       */
      currentTrial: function currentTrial(trial) {
        if (!arguments.length) {
          return _trial;
        }

        _trial = trial;
        return this;
      },

      /**
       * Get/set the current filter type for the report.
       * @param {reportEnums.filterType} filterType The filter type for
       *  this report.
       * @return Current subject if called with no arguments, otherwise this.
       */
      comparisonFilter: function comparisonFilter(filterType) {
        if (!arguments.length) {
          return _filterType;
        }

        _filterType = filterType;
        _compareTrials = reportUtils.getFilteredTrials(_trial, _subject, _filterType);
        return this;
      },

      /**
       * Get/set the current container for the report.
       * @param {d3.selection} container The container to build report in.
       * @return Current report container if called with no arguments,
       * otherwise this.
       */
      reportContainer: function reportContainer(container) {
        if (!arguments.length) {
          return _container;
        }

        _container = container;
        return this;
      },

      /**
       *`Update the report.
       * @return this.
       */
      update: function update() {
        updateReport();
        return this;
      },

      /**
       * Export the report visualization as a PNG.
       */
      exportVisAsPng: function exportVisAsPng() {
        svgExport.exportSvgToPng(_container.select('svg'));
        return this;
      },

      /**
       * Export the report visualzation as an SVG.
       */
      exportVisAsSvg: function exportVisAsSvg() {
        svgExport.exportSvgToSvg(_container.select('svg'));
        return this;
      },

      /**
       * Update the title of the report.
       */
      updateTrialTitle: function updateTrialTitle() {
        generateTitle();
      }
    };
  }

  return jointAngleReport;
});
//# sourceMappingURL=joint_angle_report_handler.js.map
