"use strict";

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

/* Copyright (c) 2016-2019 APDM, Inc.
 *
 * Strip charts for continous joint angle data.
 */
define(['jquery', 'd3', 'utils', 'progress_dialog', 'bootstrap-dialog', 'server_handler', 'model_protocol', 'app/joint_angle_data', 'single_sensor_plot', 'tinysort', 'metric_definition_helper', 'metric_utils', 'test_definition_handler', 'app/joint_definitions', 'app/user_options_handler', 'error_handler', 'pubsub', 'time_series_controls', 'time_based_controller'], function ($, d3, utils, ProgressDialog, BootstrapDialog, ServerHandler, ModelProtocol, JointAngleData, SingleSensorPlot, tinysort, MetricDefinitionHelper, metricUtils, TestDefinitionHandler, jointDefinitions, UserOptionsHandler, ErrorHandler, PubSub, TimeSeriesControls, TimeBasedController) {
  var LEFT = 'Left';
  var RIGHT = 'Right';
  var MIDDLE_JOINTS = ['Back', 'Trunk', 'Neck'];
  var LINES_COLORS = {
    'X': {
      color: 'red',
      line: 'x'
    },
    'Y': {
      color: 'green',
      line: 'y'
    },
    'Z': {
      color: 'blue',
      line: 'z'
    }
  };
  var ANNOTATION_ONE_COLOR = '#ff9626';
  var ANNOTATION_TWO_COLOR = '#1f74a5';

  var JointAngleStripPlots =
  /*#__PURE__*/
  function () {
    function JointAngleStripPlots() {
      var _this = this;

      _classCallCheck(this, JointAngleStripPlots);

      this._height = 300;
      this._width = 950;
      this._margin = {
        top: 10,
        bottom: 40,
        left: 50,
        right: 20
      };
      this._progDialog = null;
      this._container = null;
      this._trial = null;
      this._jointList = null;
      this._jointData = null;
      this._events = [];
      this._plottedJoints = [];
      this._allPlots = []; // Base data is initial data retrieved from server

      this._baseData = null; // Current data is base data plus additional that may
      // have been spliced in to give more detail when zoomed.

      this._currentData = null; // Options to control what range and what detail
      // of data to get.

      this._exportOptions = {
        displayWidth: this._width
      };
      this.dispatcher = d3.dispatch('yDomainChange', 'dataUpdate', 'renderedLinesChange'); // The current extent of the displayed data.

      this._extents = [];
      this._timeSeriesControls = null;
      this._timeSeriesControlsId = null; // Update when resize event

      this._windowResizeSub = PubSub.subscribe('window.resized', function () {
        var plotContainer = _this._container.select('.report_vis_div').node();

        if (!plotContainer || !document.body.contains(plotContainer)) {
          PubSub.unsubscribe(_this._windowResizeSub);
          _this._windowResizeSub = null;
          return;
        }

        var boundingRect = plotContainer.getBoundingClientRect();
        _this._width = boundingRect.width;

        _this._allPlots.map(function (d) {
          d.plot.width(_this._width);
          d.plot.plot(d.container);
        });
      });
    }
    /**
     * Open the dialog that will contain the plots.
     */


    _createClass(JointAngleStripPlots, [{
      key: "initDialog",
      value: function initDialog() {
        var self = this;
        var dialog = new BootstrapDialog({
          size: BootstrapDialog.SIZE_WIDE,
          closable: false,
          title: 'Joint Angle Data',
          cssClass: 'joint-angle-dialog',
          message: $('<div></div>').load('joint_angle_strip_plot.html'),
          buttons: [{
            label: 'Close',
            action: function action(dialog) {
              dialog.close();
            }
          }],
          onshown: function onshown() {
            self.getTrialEvents();
          },
          onhide: self.savePlottedJoints
        });
        dialog.open();
      }
      /**
       * Get the metrics for the trial, then parse the event
       * data and pass that on to the plot generation.
       */

    }, {
      key: "getTrialEvents",
      value: function getTrialEvents() {
        this._extents = [new Date(0), new Date(this._jointData.Duration * 1000)];
        var self = this;
        this._events = [];

        this._trial.getMetrics().then(function (metrics) {
          self.parseEventData(metrics, 0);
          self.createPlotBrush();
          self.buildInitialPlots();

          self._progDialog.close();
        }, function () {
          self.createPlotBrush();
          self.createEventKey();
          self.buildInitialPlots();

          self._progDialog.close();
        });
      }
      /**
       * Parse the event data.
       * @param {Object} metrics The trial metrics to pull events from.
       * @param {Number} startTime The time to add to the events.
       */

    }, {
      key: "parseEventData",
      value: function parseEventData(metrics, startTime) {
        var defHandler = MetricDefinitionHelper.getInstance();
        var defs = defHandler.getMetricDefinitions(this._trial.getTestName());
        var eventKeys = defHandler.getEventNames(this._trial.getTestName());
        this._events = [];
        eventKeys.forEach(function (d) {
          var def = defs.get(d);

          this._events.push({
            name: def.displayName,
            color: def.eventColor,
            events: metricUtils.getEventStartEndTimes(this._trial.getTestName(), d, metrics, startTime)
          });
        }, this); // Add any annotations is they exist. Use some wack colors

        var annotations = this._trial.getAnnotations();

        Object.keys(annotations).forEach(function (d, i) {
          var times = annotations[d].startTimes.map(function (g) {
            return {
              start: g * 1000 + startTime,
              end: g * 1000 + startTime,
              opacity: 1.0
            };
          });

          this._events.push({
            name: annotations[d].annotationLabel,
            color: i === 0 ? ANNOTATION_ONE_COLOR : ANNOTATION_TWO_COLOR,
            events: times
          });
        }, this);
        this.createEventKey();
      }
      /**
       * Build plots for the joints that were passed in on opening.
       * Also get the list of available joints.
       */

    }, {
      key: "buildInitialPlots",
      value: function buildInitialPlots() {
        this._jointList = [];
        var keys = Object.keys(this._jointData.jointAngleGroup);
        var self = this;
        keys.forEach(function (d) {
          var groupKeys = Object.keys(self._jointData.jointAngleGroup[d]);

          if (groupKeys.indexOf(LEFT) > -1 || groupKeys.indexOf(RIGHT) > -1) {
            groupKeys.forEach(function (g) {
              self._jointList.push({
                path: d + '/' + g,
                display: g + ' ' + d
              });
            });
          } else {
            self._jointList.push({
              path: d,
              display: d
            });
          }
        }); // Filter out joints that we want to plot, but are not in the
        // joint list.

        var availableJoints = this._jointList.map(function (d) {
          return d.path;
        });

        this._plottedJoints = this._plottedJoints.filter(function (d) {
          return availableJoints.indexOf(d) > -1;
        });

        if (!this._plottedJoints.length) {
          this._plottedJoints.push(availableJoints[0]);
        }

        this._plottedJoints.forEach(function (d) {
          this.createSelectAndPlot(d);
        }, this);
      }
      /**
       * Create the brush that will handle the zoom and pan on the
       * sensor plots.
       */

    }, {
      key: "createPlotBrush",
      value: function createPlotBrush() {
        this._timeSeriesControls = new TimeSeriesControls(d3.select('.sensor-plot-controls'), false).startAndEndTimes(this._extents).width(this._width).isRelative(true).update();
        this._timeSeriesControlsId = TimeBasedController.getInstance().registerElement(this._timeSeriesControls);
      }
      /**
       * Create the dropdown selection and the plot for the given joint.
       * @param {String} jointPath The joint.
       */

    }, {
      key: "createSelectAndPlot",
      value: function createSelectAndPlot(jointPath) {
        var joint = this._jointList.filter(function (d) {
          return d.path === jointPath;
        })[0];

        var container = d3.select('#joint-angle-container').select('.report_vis_div').append('div');

        if (!joint) {
          container.append('h3').style('width', '100%').style('text-align', 'center').attr('class', 'text-danger').text('No joint angle data available.');

          this._progDialog.close();

          return;
        } // Top and plot containers.


        var topContainer = container.append('div').attr('class', 'margin-10-left');
        var plotContainer = container.append('div').style('margin', '0 auto');
        this.populateSelection(jointPath, container, topContainer, plotContainer);
        this.generateJointPlot(topContainer, plotContainer, joint.path);
      }
      /**
       * Populate all the selection dropdowns after getting the list of
       * availble joints. Also add a "-" button to remove the plot.
       * @param {String} joint The joint to default selection to.
       * @param {d3.selection} container The overall container for plot and
       * select.
       * @param {d3.selection} topContainer The container above the plot.
       * @param {d3.selection} plotContainer The container to build plot in.
       */

    }, {
      key: "populateSelection",
      value: function populateSelection(joint, container, topContainer, plotContainer) {
        var selectEle = topContainer.append('select').attr('class', 'test-btn', 'joint-angle-select');
        selectEle.selectAll('option').data(this._jointList).enter().append('option').attr('value', function (d) {
          return d.path;
        }).text(function (d) {
          return d.display;
        });
        var selectNode = $(selectEle.node());
        tinysort(selectNode.find('option'));
        selectNode.selectpicker({
          width: 'auto'
        });
        selectNode.selectpicker('val', joint); // Have to keep track of the previous value.

        var self = this;
        selectNode.change(function () {
          self.generateJointPlot(topContainer, plotContainer, $(this).val());
        });
        topContainer.append('button').attr('id', 'joint-angle-remove-plot-btn').attr('class', 'btn btn-default test-btn').on('click', function () {
          container.remove();
        }).append('span').attr('class', 'iconic iconic-minus');
      }
      /**
       * Generate a plot for a given joint.
       * @param {d3.selection} topContainer The container holding selection
       * drop-down and key.
       * @param {d3.selection} plotContainer The container to build plot in.
       * @param {String} jointPath The joint to plot.
       */

    }, {
      key: "generateJointPlot",
      value: function generateJointPlot(topContainer, plotContainer, jointPath) {
        // Handle non-bilateral joints.
        if (MIDDLE_JOINTS.indexOf(jointPath) > -1) {
          jointPath = jointPath + '/Middle';
        }

        var primaryData = this.getDataToPlot(jointPath); // Unique id for container

        var id = 'id-' + Date.now();
        this.drawPlot(id, plotContainer, primaryData, jointPath);
        this.buildKey(id, jointPath, topContainer);
      }
      /**
       * Find the data that is going to be plotted.
       * @param {String} path The path for the joint data.
       * @return {JointAngleData} The data to plot.
       */

    }, {
      key: "getDataToPlot",
      value: function getDataToPlot(path) {
        if (path === 'None') {
          return null;
        }

        var splitPath = path.split('/');
        var angleData = new JointAngleData(path, this._jointData.jointAngleGroup[splitPath[0]][splitPath[1]]);
        return angleData;
      }
      /**
       * Draw the joint angle plot.
       * @param {String} id ID for the plot dispatcher.
       * @param {d3.selection} container Node to build plot in.
       * @param {JointAngleData} primaryData The primary data to plot.
       */

    }, {
      key: "drawPlot",
      value: function drawPlot(id, container, primaryData, jointPath) {
        var plot = new SingleSensorPlot().width(this._width).height(this._height).margin(this._margin).vertLabel('Angle (°)').horzLabel('Time').plotSecondary(false).relativeTime(true).doProgress(false);
        this.setDataAccessors(plot, jointDefinitions[jointPath]);
        container.datum({
          primaryData: primaryData
        });

        if (this._events.length) {
          plot.plotEvents(true);
          plot.eventData(this._events);
        }

        container.attr('id', id);
        plot.dispatcher(this.dispatcher, id);
        plot.plot(container);

        this._allPlots.push({
          plot: plot,
          container: container,
          jointData: primaryData
        });
      }
      /**
       * Set the data accessors for the plot.
       * @param {SingleSensorPlot} plot The plot to set accessors on.
       * @param {Object} jointDef The joint defintion defining valid axes.
       */

    }, {
      key: "setDataAccessors",
      value: function setDataAccessors(plot, jointDef) {
        var axes = Object.keys(jointDef.axes);
        var renderedLines = {
          x: true,
          y: true,
          z: true,
          scalar: false
        };

        if (hasAxis('X')) {
          plot.x1(function (d) {
            return d.X;
          });
        } else {
          renderedLines.x = false;
        }

        if (hasAxis('Y')) {
          plot.y1(function (d) {
            return d.Y;
          });
        } else {
          renderedLines.y = false;
        }

        if (hasAxis('Z')) {
          plot.z1(function (d) {
            return d.Z;
          });
        } else {
          renderedLines.z = false;
        }

        plot.time1(function (d) {
          return new Date(d.time);
        }).scalar1(null);

        if (hasAxis('X')) {
          plot.x2(function (d) {
            return d.X;
          });
        }

        if (hasAxis('Y')) {
          plot.y2(function (d) {
            return d.Y;
          });
        }

        if (hasAxis('Z')) {
          plot.z2(function (d) {
            return d.Z;
          });
        }

        plot.time2(function (d) {
          return d.time;
        });
        plot.renderedLines(renderedLines);

        function hasAxis(axisName) {
          return axes.indexOf(axisName) > -1;
        }
      }
      /**
       * Build the key for the plot, along with checkboxes to disable lines
       * on the plot.
       * @param {String} id The ID of the plot's dispatcher.
       * @param {String} joint The joint being plotted.
       * @param {d3.selection} container The container to build the key in.
       */

    }, {
      key: "buildKey",
      value: function buildKey(id, joint, container) {
        var axes = jointDefinitions[joint].axes;
        var values = [];
        Object.keys(axes).forEach(function (d) {
          var line = LINES_COLORS[d];
          line.name = axes[d].name;
          values.push(line);
        });
        container.selectAll('.joint-plot-key').data([joint]).enter().append('div').attr('class', 'joint-plot-key');
        var keyContainer = container.select('.joint-plot-key');
        var self = this;
        var selectionSet = keyContainer.selectAll('.key-axis-span').data(values, function (d) {
          return d.name;
        }).each(function (d) {
          var span = d3.select(this);
          var input = span.select('input').attr('type', 'checkbox').attr('id', d.line).attr('value', d.line).style('margin-right', '5px').on('click', null).on('click', function (d) {
            var changed = {};
            changed[d.line] = this.checked;
            self.dispatcher.call('renderedLinesChange', self, changed, id);
          });
          span.select('svg').attr('width', 30).attr('height', 10).select('rect').attr('x', 0).attr('y', 0).attr('width', 30).attr('height', 10).style('fill', d.color);
          span.select('span').style('margin', '0 5px').text(d.name); // Annoying jQuery hack to make sure box checked correctly

          $(input.node()).prop('checked', true);
        });
        selectionSet.exit().remove();
        selectionSet.enter().append('span').attr('class', 'key-axis-span').style('margin-right', '10px').each(function (d) {
          var span = d3.select(this);
          span.append('input').attr('type', 'checkbox').attr('id', d.line).attr('value', d.line).attr('checked', true).style('margin-right', '5px').on('click', function (d) {
            var changed = {};
            changed[d.line] = this.checked;
            self.dispatcher.call('renderedLinesChange', self, changed, id);
          });
          span.append('svg').attr('width', 30).attr('height', 10).append('rect').attr('x', 0).attr('y', 0).attr('width', 30).attr('height', 10).style('fill', d.color);
          span.append('span').style('margin', '0 5px').text(d.name);
        });
      }
      /**
       * Build a key for the events, and an "+" button to add
       * additional plots and a "reset" button for the zoom.
       */

    }, {
      key: "createEventKey",
      value: function createEventKey() {
        if (this._events && this._events.length) {
          var totalWidth = 0;
          var svg = d3.select('.event-key').append('svg').attr('width', 300).attr('height', 14);
          svg.selectAll('g').data(this._events).enter().append('g').each(function (d) {
            var g = d3.select(this);
            g.append('rect').attr('x', 0).attr('y', 0).attr('width', 30).attr('height', 10).style('fill', d.color);
            var text = g.append('text').text(d.name).attr('x', 35).attr('y', 10);
            g.attr('transform', 'translate(' + totalWidth + ',0)');
            totalWidth = totalWidth + text.node().getBBox().width + 45;
          });
          svg.attr('width', totalWidth);
        } // Create the "add plot" button.


        var div = d3.selectAll('.event-key');
        var self = this;
        div.append('button').attr('id', 'reset-joint-angle-zoom-btn').attr('class', 'btn btn-default pull-right test-btn').on('click', function () {// FIXME: Need to do something here.
        }).text('Reset Zoom');
        div.append('button').attr('id', 'add-joint-angle-plot-btn').attr('class', 'btn btn-default pull-right test-btn').on('click', function () {
          self.createSelectAndPlot(self._jointList[0].path);
        }).append('span').attr('class', 'iconic iconic-plus');
      }
      /**
       * Handle a change in the currently plotted domain.
       * @param {Array} newExtents The new domain being plotted.
       */

    }, {
      key: "domainChange",
      value: function domainChange(newExtents) {
        if (this._extents[0].getTime() === newExtents[0].getTime() && this._extents[1].getTime() === newExtents[1].getTime()) {
          return;
        }

        this._extents = newExtents;

        this._allPlots.forEach(function (d) {
          d.plot.domainChange(newExtents);
        });

        var indexes = this._findRange();

        this._sendDataRequest(indexes);
      }
      /**
       * Handle a change in the time from an animation for the plot
       * progress bars.
       * @param {Number} newTime The new time for the progress bar
       * in milliseconds.
       */

    }, {
      key: "animationTime",
      value: function animationTime(newTime) {
        this._allPlots.map(function (d) {
          d.plot.updateProgress(newTime);
        });
      }
      /**
       * Send a request for new data for the plots.
       * @param {Object} indexes Object containing start and end indexes.
       */

    }, {
      key: "_sendDataRequest",
      value: function _sendDataRequest(indexes) {
        var self = this;
        ServerHandler.getInstance().post({
          type: ModelProtocol.get_joint_angle_data,
          analysisFile: this._trial.getAnalysisFileName(),
          options: JSON.stringify({
            displayWidth: this._width,
            startRow: indexes.startIdx,
            endRow: indexes.endIdx
          })
        }, 'json', function (d) {
          self.updatePlotData(d);
        }, function (e) {
          ErrorHandler.showError(e.error().statusText);
        });
      }
      /**
       * Get the start index and end index into the array where the
       * new data should be inserted.
       * @return {Object} Map of start and end index into data array.
       */

    }, {
      key: "_findRange",
      value: function _findRange() {
        var sampleRate = 128; // FIXME: Get this from some attribute in HDF?

        var startIdx = this._extents[0] * 1000 * sampleRate * Math.pow(10, -6);
        var endIdx = (this._extents[1] - this._extents[0]) * 1000 * sampleRate * Math.pow(10, -6) + startIdx;

        if (startIdx < 0) {
          startIdx = 0;
        }

        return {
          startIdx: Math.floor(startIdx),
          endIdx: Math.ceil(endIdx)
        };
      }
      /**
       * Update plots after getting new data.
       * @param {Object} newJointData Then new data from the server
       * to splice in.
       */

    }, {
      key: "updatePlotData",
      value: function updatePlotData(newJointData) {
        var splitPath = this._plottedJoints[0].split('/');

        var newData = new JointAngleData(this._plottedJoints[0], newJointData.jointAngleGroup[splitPath[0]][splitPath[1]]).getData();
        var oldData = new JointAngleData(this._plottedJoints[0], this._jointData.jointAngleGroup[splitPath[0]][splitPath[1]]).getData();
        var startTime = newData[0].time;
        var endTime = newData[newData.length - 1].time;
        var startIdx = 0;

        while (oldData[startIdx] && oldData[startIdx].time < startTime) {
          startIdx++;
        }

        var endIdx = startIdx;

        while (oldData[endIdx] && oldData[endIdx].time < endTime) {
          endIdx++;
        } // Cut and splice the data.


        this._allPlots.forEach(function (d) {
          var split = d.jointData.getName().split('/');
          var spliceInto = new JointAngleData(d.jointData.getName(), this._jointData.jointAngleGroup[split[0]][split[1]]);
          var spliceFrom = new JointAngleData(d.jointData.getName(), newJointData.jointAngleGroup[split[0]][split[1]]);
          utils.spliceIntoArray(spliceFrom.getData(), spliceInto.getData(), startIdx, endIdx);
          d.jointData = spliceInto;
          d.container.datum().primaryData.setData(spliceInto.getData());
        }, this);

        this.dispatcher.call('dataUpdate');
      }
      /**
       * Open a joint angle strip chart, using the angle
       * data for the given trial.
       * @param {Trial} trial the trial to plot angles for.
       * @param {Array} jointsToPlot List of joints to plot
       * @param {d3.selection} container The container to build the plots
       * in. If undefined, then a separate dialog will be opened.
       * on start-up.
       */

    }, {
      key: "open",
      value: function open(trial, jointsToPlot, container) {
        this._trial = trial;
        this._plottedJoints = jointsToPlot ? jointsToPlot : [];
        this._container = container; // Open a dialog with a waiting spinner in it

        this._progDialog = new ProgressDialog({
          title: 'Loading joint angle data'
        }).show();
        var self = this;
        ServerHandler.getInstance().post({
          type: ModelProtocol.get_joint_angle_data,
          analysisFile: trial.getAnalysisFileName(),
          options: JSON.stringify(this._exportOptions)
        }, 'json', function (d) {
          self._jointData = d; // Add delays to duration.

          var testDef = TestDefinitionHandler.getInstance().getTestDefinition(self._trial.getTestName(), self._trial.getConditionName());
          self._jointData.Duration = parseFloat(self._jointData.Duration, 10) + parseInt(testDef.startDelay, 10);

          if (self._container) {
            self.getTrialEvents();
          } else {
            self.initDialog();
          }
        }, function (e) {
          self._progDialog.close();

          ErrorHandler.showError(e.error().statusText);
        });
        return this;
      }
      /**
       * Save the plotted joints to the user options on the study.
       * @return This instance.
       */

    }, {
      key: "_savePlottedJoints",
      value: function _savePlottedJoints() {
        var joints = d3.selectAll('.joint-plot-key').data();
        UserOptionsHandler.getInstance().setPlottedJointAngles(joints);
        return this;
      }
      /**
       * Set the height for the individual plots.
       * @param {Number} plotHeight The height, in pixels, for the plot.
       * @return Current height if called with no arguments, otherwise this.
       */

    }, {
      key: "height",
      value: function height(plotHeight) {
        if (!arguments.length) {
          return this._height;
        }

        this._height = plotHeight;
        return this;
      }
      /**
       * Set the margins for the individual plots.
       * @param {Object} margins The margins around the plot.
       * @return Current margins if called with no arguments, otherwise this.
       */

    }, {
      key: "margins",
      value: function margins(_margins) {
        if (!arguments.length) {
          return this._margins;
        }

        this._margins = _margins;
        return this;
      }
      /**
       * Clean up this instance.
       */

    }, {
      key: "dispose",
      value: function dispose() {
        PubSub.unsubscribe(this._windowResizeSub);

        if (this._timeSeriesControls) {
          this._timeSeriesControls.dispose();

          this._timeSeriesControls = null;
        }

        TimeBasedController.getInstance().unregisterElement(this._timeSeriesControlsId);
      }
    }]);

    return JointAngleStripPlots;
  }();

  return JointAngleStripPlots;
});
//# sourceMappingURL=joint_angle_strip_plots.js.map
