"use strict";

/* Copyright (c) 2016-2017 APDM, Inc.
 *
 * joint_definitions.js
 *
 * Definitions for the joint angles the sensors required to
 * measure them, and the names for the axes in the plot.
 */
define({
  'Neck/Middle': {
    required_sensors: ['FOREHEAD', 'STERNUM'],
    axes: {
      'X': {
        name: 'Right-Left Lateral Bending',
        domain: [-50, 50]
      },
      'Z': {
        name: 'Flexion-Extension',
        domain: [-75, 95]
      },
      'Y': {
        name: 'Right-Left Rotation',
        domain: [-90, 90]
      }
    }
  },
  'Back/Middle': {
    required_sensors: ['STERNUM', 'LUMBAR'],
    axes: {
      'X': {
        name: 'Right-Left Lateral Bending',
        domain: [-50, 50]
      },
      'Z': {
        name: 'Flexion-Extension',
        domain: [-35, 90]
      },
      'Y': {
        name: 'Right-Left Rotation',
        domain: [-50, 50]
      }
    }
  },
  //    'Clavicle/Right': {
  //        required_sensors: ['STERNUM', 'RIGHT_CLAVICLE'],
  //        axes: {
  //            'X': { name: 'Protaction-Retraction',
  //                   domain: [-35, 35] },
  //            'Z': { name: 'Elevation-Depression',
  //                   domain: [-20, 55] },
  //            'Y': { name: 'Anterior-Posterior Rotation',
  //                   domain: [-55, 55] }
  //        }
  //    },
  //    'Clavicle/Left': {
  //        required_sensors: ['STERNUM', 'LEFT_CLAVICLE'],
  //        axes: {
  //            'X': { name: 'Protaction-Retraction',
  //                   domain: [-35, 35] },
  //            'Z': { name: 'Elevation-Depression',
  //                   domain: [-20, 55] },
  //            'Y': { name: 'Anterior-Posterior Rotation',
  //                   domain: [-55, 55] }
  //        }
  //    },
  'Shoulder/Right': {
    required_sensors: ['STERNUM', 'RIGHT_UPPER_ARM'],
    axes: {
      'X': {
        name: 'Abduction-Adduction',
        domain: [-80, 185]
      },
      'Z': {
        name: 'Flexion-Extension',
        domain: [-65, 185]
      },
      'Y': {
        name: 'Internal-External Rotation',
        domain: [-95, 95]
      }
    }
  },
  'Shoulder/Left': {
    required_sensors: ['STERNUM', 'LEFT_UPPER_ARM'],
    axes: {
      'X': {
        name: 'Abduction-Adduction',
        domain: [-80, 185]
      },
      'Z': {
        name: 'Flexion-Extension',
        domain: [-65, 185]
      },
      'Y': {
        name: 'Internal-External Rotation',
        domain: [-95, 95]
      }
    }
  },
  'Elbow/Right': {
    required_sensors: ['RIGHT_UPPER_ARM', 'RIGHT_WRIST'],
    axes: {
      'Y': {
        name: 'Supination-Pronation',
        domain: [-95, 95]
      },
      'Z': {
        name: 'Flexion-Extension',
        domain: [-5, 155]
      }
    }
  },
  'Elbow/Left': {
    required_sensors: ['LEFT_UPPER_ARM', 'LEFT_WRIST'],
    axes: {
      'Y': {
        name: 'Supination-Pronation',
        domain: [-95, 95]
      },
      'Z': {
        name: 'Flexion-Extension',
        domain: [-5, 155]
      }
    }
  },
  'Wrist/Right': {
    required_sensors: ['RIGHT_WRIST', 'RIGHT_HAND'],
    axes: {
      'X': {
        name: 'Flexion-Extension',
        domain: [-75, 95]
      },
      'Z': {
        name: 'Ulnar-Radial Deviation',
        domain: [-35, 50]
      }
    }
  },
  'Wrist/Left': {
    required_sensors: ['LEFT_WRIST', 'LEFT_HAND'],
    axes: {
      'X': {
        name: 'Flexion-Extension',
        domain: [-75, 95]
      },
      'Z': {
        name: 'Ulnar-Radial Deviation',
        domain: [-35, 50]
      }
    }
  },
  'Hip/Right': {
    required_sensors: ['LUMBAR', 'RIGHT_UPPER_LEG'],
    axes: {
      'X': {
        name: 'Abduction-Adduction',
        domain: [-35, 75]
      },
      'Z': {
        name: 'Flexion-Extension',
        domain: [-35, 145]
      },
      'Y': {
        name: 'Internal-External Rotation',
        domain: [-65, 65]
      }
    }
  },
  'Hip/Left': {
    required_sensors: ['LUMBAR', 'LEFT_UPPER_LEG'],
    axes: {
      'X': {
        name: 'Abduction-Adduction',
        domain: [-35, 75]
      },
      'Z': {
        name: 'Flexion-Extension',
        domain: [-35, 145]
      },
      'Y': {
        name: 'Internal-External Rotation',
        domain: [-65, 65]
      }
    }
  },
  'Knee/Right': {
    required_sensors: ['RIGHT_UPPER_LEG', 'RIGHT_LOWER_LEG'],
    axes: {
      'X': {
        name: 'Valgus-Varus',
        domain: [-20, 20]
      },
      'Z': {
        name: 'Flexion-Extension',
        domain: [-5, 155]
      },
      'Y': {
        name: 'Internal-External Rotation',
        domain: [-20, 20]
      }
    }
  },
  'Knee/Left': {
    required_sensors: ['LEFT_UPPER_LEG', 'LEFT_LOWER_LEG'],
    axes: {
      'X': {
        name: 'Valgus-Varus',
        domain: [-20, 20]
      },
      'Z': {
        name: 'Flexion-Extension',
        domain: [-5, 155]
      },
      'Y': {
        name: 'Internal-External Rotation',
        domain: [-20, 20]
      }
    }
  },
  'Ankle/Right': {
    required_sensors: ['RIGHT_LOWER_LEG', 'RIGHT_FOOT'],
    axes: {
      'X': {
        name: 'Eversion-Inversion',
        domain: [-35, 55]
      },
      'Z': {
        name: 'Dorsiflexion-Plantarflexion',
        domain: [-25, 55]
      },
      'Y': {
        name: 'Abduction-Adduction',
        domain: [-25, 25]
      }
    }
  },
  'Ankle/Left': {
    required_sensors: ['LEFT_LOWER_LEG', 'LEFT_FOOT'],
    axes: {
      'X': {
        name: 'Eversion-Inversion',
        domain: [-35, 55]
      },
      'Z': {
        name: 'Dorsiflexion-Plantarflexion',
        domain: [-25, 55]
      },
      'Y': {
        name: 'Abduction-Adduction',
        domain: [-25, 25]
      }
    }
  }
});
//# sourceMappingURL=joint_definitions.js.map
