"use strict";

/* Copyright (c) 2017 APDM, Inc.
 *
 * login_menu_handler.js
 *
 * Initialize the items in the login menu.
 */
define(['jquery', 'server_handler', 'app/exchange_handler', 'app/user_options_handler', 'app/upload_handler', 'app/login_handler'], function ($, ServerHandler, ExchangeHandler, OptionsHandler, UploadHandler, LightweightLoginHandler) {
  'use strict';

  var _instance;

  var _exchange;

  var _uploadHandler;

  var _options;

  function init() {
    _exchange = ExchangeHandler.getInstance();
    _uploadHandler = UploadHandler.getInstance();
    _options = OptionsHandler.getInstance(); // Determine what handlers should be attached to the
    // login/cloud menu.

    if (ServerHandler.getInstance().hasJsPostHandler()) {
      setupForMobilityWeb();
    } else if (_exchange.associatedWithServer()) {
      setupForExchange();
    } else if (_options.hasHttpBackup() && !ServerHandler.getInstance().hasJsPostHandler()) {
      setupForHttpBackup();
    } else if (_options.getRequireLightweightLogin()) {
      setupForLightweightLogin();
    }

    return {
      refresh: function refresh() {
        _instance = init();
        return _instance;
      }
    };
  }
  /**
   * Setup the menu for a Mobility Web instance.
   */


  function setupForMobilityWeb() {
    $('#mobility-exchange-menu').css('display', 'block');
    var newConnection = $('#exchange-new-connection');
    var loginBtn = $('#exchange-login');
    var uploadBtn = $('#exchange-upload');
    newConnection.off('click');
    loginBtn.off('click');
    uploadBtn.off('click'); // Remove unneeded buttons

    newConnection.remove();
    uploadBtn.remove();
    loginBtn.removeClass('disabled');

    if (_exchange.loggedIn()) {
      loginBtn.find('.iconic').removeClass('iconic-account-login').addClass('iconic-account-logout');
      loginBtn.find('#exchange-login-text').text('Logout');
      loginBtn.click(_exchange.logout);
      uploadBtn.addClass('enabled').removeClass('disabled');
      uploadBtn.click(function () {
        _uploadHandler.uploadTrials(true);
      });
    } else {
      loginBtn.find('.iconic').removeClass('iconic-account-logout').addClass('iconic-account-login');
      loginBtn.find('#exchange-login-text').text('Login');
      loginBtn.click(_exchange.login);
      uploadBtn.addClass('disabled').removeClass('enabled');
    }

    $('#exchange-user-info').click(_exchange.userInfo);
  }
  /**
   * Setup the login/cloud menu for Mobility Exchange.
   */


  function setupForExchange() {
    $('#mobility-exchange-menu').css('display', 'block');
    var newConnection = $('#exchange-new-connection');
    var loginBtn = $('#exchange-login');
    var uploadBtn = $('#exchange-upload');
    newConnection.off('click');
    loginBtn.off('click');
    uploadBtn.off('click');

    if (_exchange.associatedWithServer()) {
      newConnection.addClass('disabled');
      loginBtn.removeClass('disabled');

      if (_exchange.loggedIn()) {
        loginBtn.find('.iconic').removeClass('iconic-account-login').addClass('iconic-account-logout');
        loginBtn.find('#exchange-login-text').text('Logout');
        loginBtn.click(function () {
          _uploadHandler.uploadTrials(false, true);
        });
        uploadBtn.addClass('enabled').removeClass('disabled');
        uploadBtn.click(function () {
          _uploadHandler.uploadTrials(true);
        });
      } else {
        loginBtn.find('.iconic').removeClass('iconic-account-logout').addClass('iconic-account-login');
        loginBtn.find('#exchange-login-text').text('Login');
        loginBtn.click(_exchange.login);
        uploadBtn.addClass('disabled').removeClass('enabled');
      }
    } else {
      newConnection.removeClass('disabled');
      newConnection.click(_exchange.setupNewServerConnection);
      loginBtn.addClass('disabled');
      uploadBtn.addClass('disabled').removeClass('enabled');
    }

    $('#exchange-user-info').click(_exchange.userInfo);
  }
  /**
   * Setup the login/cloud menu for handling HTTP backup.
   */


  function setupForHttpBackup() {
    $('#mobility-exchange-menu').css('display', 'block');
    $('#exchange-new-connection').css('display', 'none');
    $('#exchange-user-info').css('display', 'none');
    var loginBtn = $('#exchange-login');
    var uploadBtn = $('#exchange-upload');
    loginBtn.off('click');
    uploadBtn.off('click');
    uploadBtn.click(function () {
      _uploadHandler.uploadTrials(true);
    });

    if (_options.getRequireLightweightLogin()) {
      setupForLightweightLogin();
    } else {
      loginBtn.css('display', 'none');
    }
  }
  /**
   * Setup the login/cloud menu for handling lightweight login.
   */


  function setupForLightweightLogin() {
    $('#mobility-exchange-menu').css('display', 'block');
    $('#exchange-new-connection').css('display', 'none');
    $('#exchange-user-info').css('display', 'none');
    var loginBtn = $('#exchange-login');
    var uploadBtn = $('#exchange-upload');
    loginBtn.off('click');
    uploadBtn.off('click');
    loginBtn.find('#exchange-login-text').text('Logout');

    if (!_options.hasHttpBackup()) {
      uploadBtn.css('display', 'none');
    }

    loginBtn.click(LightweightLoginHandler.getInstance().logoutLightweightUser);
  }

  return {
    getInstance: function getInstance() {
      if (!_instance) {
        _instance = init();
      }

      return _instance;
    }
  };
});
//# sourceMappingURL=login_menu_handler.js.map
