"use strict";

/* Copyright (c) 2015-2017 APDM, Inc.
 *
 * metric_selection_tabs.js
 */
define(['jquery', 'd3', 'crossroads', 'utils', 'test_definition_handler', 'metric_definition_helper', 'res_req_map'], function ($, d3, crossroads, utils, TestDefinitionHandler, MetricDefinitionHelper, ResReqMap) {
  'use strict';

  var container;
  var group;
  var isDialog;

  var _helper;

  var _changeCallback;

  var _currentTab = null;
  var route;
  var jointAngleText = '</br>In addition to the metrics displayed on this page that can be selected for reporting, ' + 'this test type also supports the estimation of joint angles continuously throughout the entire recording:' + '<ul style="list-style-type:disc">' + '<li>The joint angles available will be dependent on which sensors are used and where they are placed on the subject</li>' + '<li>The joint angles can be plotted from within the report</li>' + '<li>The joint angles can be exported to either HDF or CSV format for further analysis</li>' + '</ul>';
  /**
   * Add a route to handle updating.
   */

  route = crossroads.addRoute('updateMetricSelectionTabs/{key}', function (key) {
    group = ResReqMap.getInstance().getRequestData(key);
    testMetricTabs();
  });
  /**
   * Build the tabs for each test type and populate it given the
   * current set metric group and its selections.
   * @param {String} test The name of the test tab to have open.
   */

  function testMetricTabs(test) {
    if (!container) {
      return;
    } // TODO: Don't like this. Seems that instances hang around because
    // of the crossroads route, so it this isn't done, old instances will
    // be called if there was a previous instance.


    if (!$(container.node()).is(':visible')) {
      crossroads.removeRoute(route);
    }

    var testNames = TestDefinitionHandler.getInstance().getTestNameMap();
    var idPostfix = '';

    if (isDialog === true) {
      idPostfix = '-dialog';
    }

    var tabListId = 'metric-tab-list' + idPostfix;
    var tabContentId = 'metric-tab-content' + idPostfix; // Handle no test types

    if (!testNames.length) {
      container.append('h3').text('No tests currently available.');
      return;
    }

    var tabDivEnter = container.selectAll('#' + tabListId).data([testNames]).enter();
    tabDivEnter.append('ul').attr('id', tabListId).attr('class', 'nav nav-tabs');
    tabDivEnter.append('div').attr('id', tabContentId).attr('class', 'options-tab-checkbox-content tab-content');
    var tabList = container.select('#' + tabListId).selectAll('li').data(testNames, function (d) {
      return d.name;
    });
    tabList.enter().append('li').append('a').attr('href', function (d) {
      return '#metric-test-tab-' + utils.makeHtmlId(d.name) + idPostfix;
    }).attr('data-toggle', 'tab').text(function (d) {
      return d.displayName;
    }).each(function () {
      $(d3.select(this).node()).on('shown.bs.tab', function (evt) {
        _currentTab = $(evt.target).attr('href');
      });
    });
    tabList.exit().remove();
    var tabContent = container.select('#' + tabContentId).selectAll('div').data(testNames, function (d) {
      return d.name;
    });
    tabContent.enter().append('div').attr('class', 'tab-pane').attr('id', function (d) {
      return 'metric-test-tab-' + utils.makeHtmlId(d.name) + idPostfix;
    });
    tabContent.exit().remove();
    container.selectAll('.tab-pane').each(function (d) {
      buildMetricSelectTable(d3.select(this), d);
    });

    if (!_currentTab && !test) {
      $('#' + tabListId + ' a:first').tab('show');
    } else if (test) {
      $('a[href="' + '#metric-test-tab-' + utils.makeHtmlId(test) + idPostfix + '"]').tab('show');
    } else {
      $('a[href="' + _currentTab + '"]').tab('show');
    }
  }
  /**
   * Build the list of metrics in a tab for the given test.
   * @param {d3.selection} tab The container to build list in.
   * @param {Object} testNames The names of the test.
   */


  function buildMetricSelectTable(tab, test) {
    var formBox = tab.append('div').attr('class', 'form-group metric-select-form').append('div').attr('class', 'container-fluid');
    var colFmt = 'col-md-6 col-lg-3';

    if (isDialog === true) {
      colFmt = 'col-sm-12 col-md-6 col-lg-6';
    }

    var metricGroups = [];
    var ordering = MetricDefinitionHelper.getInstance().getTestMetricsOrder(test.name);
    ordering.groups.forEach(function (d) {
      metricGroups.push(filterGroup(d, test.name));
    });
    var selected = [];

    var updatedMetrics = _helper.getUpdated();

    if (updatedMetrics[group].selections[test.name]) {
      selected = updatedMetrics[group].selections[test.name];
    }

    if (test && test.name === 'Free Form' || test.name === 'MLK Walk') {
      addMetricGroupTextArea(formBox, 'Joint Angles', jointAngleText);
    }

    metricGroups.forEach(function (d) {
      buildMetricGroup(test, d, formBox, updatedMetrics);
      checkboxSelections(formBox, selected);
    });
  }
  /**
   * Filter out Events and metrics not to show in the UI for
   * the metrics in the given group.
   * @param {String} groupName The name of the metric group.
   * @param {String} testName The name of the test.
   * @return {Object} Keys for name of metric group and the list
   * of metrics to display.
   */


  function filterGroup(groupName, testName) {
    var metrics = [];
    var metricGroups = MetricDefinitionHelper.getInstance().getMetricDefinitionsByGroup(testName);
    var groupDisplayName = metricGroups[groupName][0].metricGroupDisplayName;
    metricGroups[groupName].forEach(function (d) {
      if (d.metricClass !== 'Events' && d.promoteToUI === true) {
        var fullName = d.metricGroup + '/' + d.metricName;

        if (d.metricGroup === '') {
          fullName = d.metricName;
        }

        metrics.push({
          fullName: fullName,
          displayName: d.displayName
        });
      }
    });
    return {
      name: groupDisplayName,
      metrics: metrics
    };
  }
  /**
   * Build the Bootstrap DOM elements for a metric group.
   * @param {Object} test The test name and display name.
   * @param {Object} metricGroup The metric group.
   * @param {d3.selection} formBox The contianer to populate.
   * @param {Object} updatedMetrics The selected metrics.
   */


  function buildMetricGroup(test, metricGroup, formBox, updatedMetrics) {
    // Build the metrics into the Bootstrap grid.
    if (!metricGroup.metrics.length) {
      return;
    }

    var colFmt = 'col-md-6 col-lg-3';

    if (isDialog === true) {
      colFmt = 'col-sm-12 col-md-6 col-lg-6';
    }

    var selected = [];

    if (updatedMetrics[group].selections[test]) {
      selected = updatedMetrics[group].selections[test];
    }

    var groupDiv = formBox.append('div').attr('class', colFmt);
    var name = metricGroup.name;

    if (name && name !== '') {
      var id = utils.makeHtmlId(name);
      groupDiv.attr('id', id);
      var smallEle = groupDiv.append('h4').text(name).append('small');
      smallEle.append('button').data([id]).attr('class', 'btn btn-link has-modify-study').attr('id', id + '-select-all').text('Select All').on('click', function () {
        var groupId = d3.select(this).data()[0];
        formBox.select('#' + groupId).selectAll('input').each(function () {
          $(d3.select(this).node()).prop('checked', true);
        });
        doCallback();
      });
      smallEle.append('button').attr('class', 'btn btn-link has-modify-study').attr('id', id + '-deselect-all').data([id]).text('Deselect').on('click', function () {
        var groupId = d3.select(this).data()[0];
        formBox.select('#' + groupId).selectAll('input').each(function () {
          $(d3.select(this).node()).prop('checked', false);
        });
        doCallback();
      });
    }

    groupDiv.selectAll('div').data(metricGroup.metrics).enter().append('div').attr('class', 'checkbox').each(function (d) {
      d3.select(this).append('label').on('click', doCallback).html('<input class="has-modify-study" ' + 'type="checkbox" id="' + test.name + '" value="' + d.fullName + '"></input>' + d.displayName);
    });
    $(groupDiv.node()).find('input').prop('checked', false);
  }
  /**
   * Build the Bootstrap DOM elements for a metric group.
   * @param {Object} test The test name and display name.
   * @param {Object} metricGroup The metric group.
   * @param {d3.selection} formBox The contianer to populate.
   * @param {Object} updatedMetrics The selected metrics.
   */


  function addMetricGroupTextArea(formBox, title, text) {
    var colFmt = 'col-md-6 col-lg-3';

    if (isDialog === true) {
      colFmt = 'col-sm-12 col-md-6 col-lg-6';
    }

    var groupDiv = formBox.append('div').attr('class', colFmt);
    var id = utils.makeHtmlId(title);
    groupDiv.attr('id', id);
    groupDiv.append('h4').text(title);
    groupDiv.html(text);
  }
  /**
   * Check the checkboxes for the currently selected metrics.
   * @param {d3.selection} formBox The container for the
   * checkboxes.
   * @param {Array} selected The currently selected metrics.
   */


  function checkboxSelections(formBox, selected) {
    formBox.selectAll('input').attr('checked', null);
    var allCheckboxes = formBox.selectAll('label');
    allCheckboxes.each(function (d) {
      for (var i = 0; i < selected.length; i++) {
        if (d.fullName === selected[i]) {
          $(d3.select(this).select('input').node()).prop('checked', true);
        }
      }
    });
  }
  /**
   * Call the callback supplied with the current set of checked
   * metrics.
   */


  function doCallback() {
    if (_changeCallback && _changeCallback instanceof Function) {
      _changeCallback();
    }
  }

  return {
    /**
     * Create the metric selection tabs.
     * @param {MetricSelectionHelper} helper The MetricSelectionHelper
     * instance.
     * @param {String} group The name of the selection group
     * being viewed.
     * @param {String} containerId The id of the container to build
     * metric selection tabs in.
     * param {Function} callback Function to call when metric selections
     * are changed.
     * @param {Boolean} inDialog Are tabs being built in a dialog.
     * @param {String} testName The name of the test tab to make active.
     * @return this.
     */
    create: function create(helper, groupName, containerId, callback, inDialog, testName) {
      group = groupName;
      container = d3.select(containerId);
      isDialog = inDialog;
      _changeCallback = callback;
      _helper = helper;
      testMetricTabs(testName);
      return this;
    },

    /**
     * Get or set the callback function used when metric selections
     * change.
     * @param {Function} cb New callback function.
     * @return {Function} The current callback function, if called with
     * no arguments. Otherwise this.
     */
    changeCallback: function changeCallback(cb) {
      if (!arguments.length) {
        return _changeCallback;
      }

      _changeCallback = cb;
      return this;
    },

    /**
     * Get or set the selection group being viewed. If set, updates
     * the tabs.
     * @param {String} sg The new selection group.
     * @return {String} The current selection group if called with
     * no arguments. Otherwise this.
     */
    selectionGroup: function selectionGroup(sg) {
      if (!arguments.length) {
        return group;
      }

      group = sg;
      this.update();
      return this;
    },

    /**
     * Update the tabs
     * @return this.
     */
    update: function update() {
      testMetricTabs();
      return this;
    },

    /**
     * Get the currently selected metrics, and pack them
     * in an object keyed by the test name.
     * @return {Object} Lists of the selected metrics keyed by
     * the test name.
     */
    getSelected: function getSelected() {
      var testNames = TestDefinitionHandler.getInstance().getTestNameMap().map(function (d) {
        return d.name;
      });
      var selected = {};
      var checked = $('.metric-select-form :checked');
      testNames.forEach(function (d) {
        var metrics = [];
        checked.each(function () {
          if ($(this).prop("id") === d) {
            metrics.push($(this).val());
          }
        });
        selected[d] = {
          test: d,
          metrics: metrics
        };
      });
      return selected;
    }
  };
});
//# sourceMappingURL=metric_selection_tabs.js.map
