"use strict";

/* Copyright (c) 2016-2017 APDM, Inc.
 *
 * metric_vis_map.js
 *
 * Map of metrics to visualization type and SVG file using
 * the base name of the metric as key.
 */
define(['app/report_enums', 'app/unilateral_numeric_vis', 'app/unilateral_bar_vis', 'app/unilateral_speedo_vis', 'app/unilateral_arc_vis', 'app/unilateral_clock_vis', 'app/bilateral_one_norm_bar_vis', 'app/bilateral_one_norm_arc_vis', 'app/bilateral_two_norm_arc_vis'], function (enums, UnilateralNumericVis, UnilateralBarVis, UnilateralSpeedoVis, UnilateralArcVis, UnilateralClockVis, BilateralOneNormBarVis, BilateralOneNormArcVis, BilateralTwoNormArcVis) {
  var DEFAULT_UNI_BAR_RANGE = [258, 14];
  var DEFAULT_BI_BAR_RANGE = [241, 14];
  var MOBILITY_LAB_BASE = '../../mobility_clinic/res/';
  return {
    /**
     * Standard "Walk" trial metrics.
     */
    'Duration': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralNumericVis,
      baseSvg: MOBILITY_LAB_BASE + 'duration_vis.svg'
    },
    'Gait/Lower Limb/Cadence': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'cadence_vis.svg',
      options: {
        'domain': [0, 150],
        'range': DEFAULT_BI_BAR_RANGE,
        'subjectDigitPrecision': 3
      }
    },
    'Gait/Lower Limb/Double Support': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'double_support.svg',
      options: {
        'domain': [0, 50],
        'range': DEFAULT_BI_BAR_RANGE
      }
    },
    'Gait/Lower Limb/Terminal Double Support': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'terminal_double_support_vis.svg',
      options: {
        'domain': [0, 50],
        'range': DEFAULT_BI_BAR_RANGE
      }
    },
    'Gait/Lower Limb/Elevation at Midswing': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'foot_clearance_vis.svg',
      options: {
        'domain': [0, 10],
        'range': DEFAULT_BI_BAR_RANGE
      }
    },
    'Gait/Lower Limb/Gait Cycle Duration': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'gait_cycle_duration_vis.svg',
      options: {
        'domain': [0, 5],
        'range': DEFAULT_BI_BAR_RANGE
      }
    },
    'Gait/Lower Limb/Gait Speed': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'gait_speed_vis.svg',
      options: {
        'domain': [0, 4],
        'range': DEFAULT_BI_BAR_RANGE
      }
    },
    'Gait/Lower Limb/Lateral Swing Max': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'lateral_swing_max_vis.svg',
      options: {
        'domain': [0, 10],
        'range': DEFAULT_BI_BAR_RANGE
      }
    },
    'Gait/Lower Limb/Pitch at Initial Contact': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'initial_contact_vis_base.svg',
      options: {
        'offsetAngle': 90,
        'switchSign': true
      }
    },
    'Gait/Lower Limb/Pitch at Toe Off': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'toe_off_vis.svg',
      options: {
        'offsetAngle': -90
      }
    },
    'Gait/Lower Limb/Lateral Step Variability': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'lateral_step_variability_vis.svg',
      options: {
        'domain': [0, 10],
        'range': DEFAULT_BI_BAR_RANGE
      }
    },
    'Gait/Lower Limb/Step Duration': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'step_duration_vis.svg',
      options: {
        'domain': [0, 2],
        'range': DEFAULT_BI_BAR_RANGE
      }
    },
    'Gait/Lower Limb/Stance': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'stance_vis.svg',
      options: {
        'domain': [0, 75],
        'range': DEFAULT_BI_BAR_RANGE
      }
    },
    'Gait/Lower Limb/Stride Length': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'stride_length_vis.svg',
      options: {
        'domain': [0, 2],
        'range': DEFAULT_BI_BAR_RANGE
      }
    },
    'Gait/Lower Limb/Swing': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'swing_vis.svg',
      options: {
        'domain': [0, 50],
        'range': DEFAULT_BI_BAR_RANGE
      }
    },
    'Gait/Lower Limb/Toe Out Angle': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralTwoNormArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'toe_out_vis.svg'
    },
    'Gait/Head/Coronal Range of Motion': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'head_rom_coronal_vis.svg',
      options: {
        'domain': [0, 10],
        'range': DEFAULT_UNI_BAR_RANGE
      }
    },
    'Gait/Head/Sagittal Range of Motion': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'head_rom_sagittal_vis.svg',
      options: {
        'domain': [0, 10],
        'range': DEFAULT_UNI_BAR_RANGE
      }
    },
    'Gait/Head/Transverse Range of Motion': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'head_rom_transverse_vis.svg',
      options: {
        'domain': [0, 10],
        'range': DEFAULT_UNI_BAR_RANGE
      }
    },
    'Gait/Lumbar/Coronal Range of Motion': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'lumbar_rom_coronal_vis.svg',
      options: {
        'domain': [0, 25],
        'range': DEFAULT_UNI_BAR_RANGE
      }
    },
    'Gait/Lumbar/Sagittal Range of Motion': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'lumbar_rom_sagittal_vis.svg',
      options: {
        'domain': [0, 25],
        'range': DEFAULT_UNI_BAR_RANGE
      }
    },
    'Gait/Lumbar/Transverse Range of Motion': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'lumbar_rom_transverse_vis.svg',
      options: {
        'domain': [0, 25],
        'range': DEFAULT_UNI_BAR_RANGE
      }
    },
    'Gait/Trunk/Coronal Range of Motion': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'trunk_rom_coronal_vis.svg',
      options: {
        'domain': [0, 25],
        'range': DEFAULT_UNI_BAR_RANGE
      }
    },
    'Gait/Trunk/Sagittal Range of Motion': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'trunk_rom_sagittal_vis.svg',
      options: {
        'domain': [0, 25],
        'range': DEFAULT_UNI_BAR_RANGE
      }
    },
    'Gait/Trunk/Transverse Range of Motion': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'trunk_rom_transverse_vis.svg',
      options: {
        'domain': [0, 25],
        'range': DEFAULT_UNI_BAR_RANGE
      }
    },
    'Gait/Upper Limb/Maximum Velocity': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'arm_swing_velocity_vis.svg',
      options: {
        'domain': [0, 500],
        'range': DEFAULT_BI_BAR_RANGE,
        'subjectDigitPrecision': 3
      }
    },
    'Gait/Upper Limb/Range of Motion': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'upper_limb_rom_vis.svg',
      options: {
        'domain': [0, 100],
        'range': DEFAULT_BI_BAR_RANGE
      }
    },

    /**
     * Turn metrics. Appear in both "Walk" and "TUG" trials.
     */
    'Turns/Angle': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralClockVis,
      baseSvg: MOBILITY_LAB_BASE + 'turn_angle_vis.svg',
      options: {
        'domain': [0, 360],
        'subjectDigitPrecision': 3
      }
    },
    'Turns/Duration': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'turn_duration_vis.svg',
      options: {
        'domain': [0, 5],
        'range': DEFAULT_UNI_BAR_RANGE
      }
    },
    'Turns/Peak Velocity': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralSpeedoVis,
      baseSvg: MOBILITY_LAB_BASE + 'turning_velocity_vis.svg',
      options: {
        'domain': [0, 360],
        'subjectDigitPrecision': 3
      }
    },
    'Turns/Steps': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'turn_steps_vis.svg',
      options: {
        'domain': [0, 10],
        'range': DEFAULT_UNI_BAR_RANGE
      }
    },

    /**
     * APA metrics in "Walk" trials
     */
    'Anticipatory Postural Adjustment/APA Duration': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'apa_duration_vis.svg',
      options: {
        'domain': [0, 2],
        'range': DEFAULT_UNI_BAR_RANGE
      }
    },
    'Anticipatory Postural Adjustment/First Step Duration': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'first_step_duration_vis.svg',
      options: {
        'domain': [0, 2],
        'range': DEFAULT_UNI_BAR_RANGE
      }
    },
    'Anticipatory Postural Adjustment/First Step Range of Motion': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'first_step_rom_vis.svg',
      options: {
        'domain': [0, 180],
        'range': DEFAULT_UNI_BAR_RANGE
      }
    },
    'Anticipatory Postural Adjustment/Maximum AP Acceleration': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'apa_max_acceleration_saggital.svg',
      options: {
        'domain': [0, 2],
        'range': DEFAULT_UNI_BAR_RANGE
      }
    },
    'Anticipatory Postural Adjustment/Maximum ML Acceleration': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'apa_max_acceleration_coronal.svg',
      options: {
        'domain': [0, 2],
        'range': DEFAULT_UNI_BAR_RANGE
      }
    },

    /**
     * Metrics for "Sit to Stand" trials.
     */
    'Sit to Stand/Duration': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'sit_to_stand_duration_vis.svg',
      options: {
        'domain': [0, 10],
        'range': DEFAULT_UNI_BAR_RANGE
      }
    },
    'Sit to Stand/Lean Angle': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'sit_to_stand_angle_vis.svg'
    },
    'Stand to Sit/Duration': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'stand_to_sit_duration_vis.svg',
      options: {
        'domain': [0, 10],
        'range': DEFAULT_UNI_BAR_RANGE
      }
    },
    'Stand to Sit/Lean Angle': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'stand_to_sit_angle_vis.svg'
    },

    /**
     * Metrics for Sway metrics.
     */
    'Postural Sway/Angles/Duration': {
      type: enums.metricVisType.STABILOGRAM
    },
    'Postural Sway/Angles/95% Ellipse Sway Area': {
      type: enums.metricVisType.STABILOGRAM
    },
    'Postural Sway/Angles/RMS Sway': {
      type: enums.metricVisType.STABILOGRAM
    },
    'Postural Sway/Angles/RMS Sway (Coronal)': {
      type: enums.metricVisType.STABILOGRAM
    },
    'Postural Sway/Angles/RMS Sway (Sagittal)': {
      type: enums.metricVisType.STABILOGRAM
    },
    'Postural Sway/Acc/95% Ellipse Sway Area': {
      type: enums.metricVisType.STABILOGRAM
    },
    'Postural Sway/Acc/RMS Sway': {
      type: enums.metricVisType.STABILOGRAM
    },
    'Postural Sway/Acc/RMS Sway (Coronal)': {
      type: enums.metricVisType.STABILOGRAM
    },
    'Postural Sway/Acc/RMS Sway (Sagittal)': {
      type: enums.metricVisType.STABILOGRAM
    },
    'Postural Sway/Acc/Centroidal Frequency': {
      type: enums.metricVisType.STABILOGRAM
    },
    'Postural Sway/Acc/Centroidal Frequency (Coronal)': {
      type: enums.metricVisType.STABILOGRAM
    },
    'Postural Sway/Acc/Centroidal Frequency (Sagittal)': {
      type: enums.metricVisType.STABILOGRAM
    },
    'Postural Sway/Acc/Frequency Dispersion': {
      type: enums.metricVisType.STABILOGRAM
    },
    'Postural Sway/Acc/Frequency Dispersion (Coronal)': {
      type: enums.metricVisType.STABILOGRAM
    },
    'Postural Sway/Acc/Frequency Dispersion (Sagittal)': {
      type: enums.metricVisType.STABILOGRAM
    },
    'Postural Sway/Acc/Jerk': {
      type: enums.metricVisType.STABILOGRAM
    },
    'Postural Sway/Acc/Jerk (Coronal)': {
      type: enums.metricVisType.STABILOGRAM
    },
    'Postural Sway/Acc/Jerk (Sagittal)': {
      type: enums.metricVisType.STABILOGRAM
    },
    'Postural Sway/Acc/Mean Velocity': {
      type: enums.metricVisType.STABILOGRAM
    },
    'Postural Sway/Acc/Mean Velocity (Coronal)': {
      type: enums.metricVisType.STABILOGRAM
    },
    'Postural Sway/Acc/Mean Velocity (Sagittal)': {
      type: enums.metricVisType.STABILOGRAM
    },
    'Postural Sway/Acc/Path Length': {
      type: enums.metricVisType.STABILOGRAM
    },
    'Postural Sway/Acc/Path Length (Coronal)': {
      type: enums.metricVisType.STABILOGRAM
    },
    'Postural Sway/Acc/Path Length (Sagittal)': {
      type: enums.metricVisType.STABILOGRAM
    },
    'Postural Sway/Acc/Range': {
      type: enums.metricVisType.STABILOGRAM
    },
    'Postural Sway/Acc/Range (Coronal)': {
      type: enums.metricVisType.STABILOGRAM
    },
    'Postural Sway/Acc/Range (Sagittal)': {
      type: enums.metricVisType.STABILOGRAM
    },

    /**
     * RoM metrics from Mobility Lab Kinematics Walk.
     */
    // Neck
    'Gait/Joint/Neck/Abduction/Maximum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'neck_abduction_maximum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Neck/Abduction/Minimum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'neck_abduction_minimum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Neck/Abduction/ROM': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'neck_abduction_rom.svg',
      options: {
        'domain': [0, 100],
        'range': DEFAULT_BI_BAR_RANGE
      }
    },
    'Gait/Joint/Neck/Flexion/Maximum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'neck_flexion_maximum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Neck/Flexion/Minimum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'neck_flexion_minimum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Neck/Flexion/ROM': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'neck_flexion_rom.svg',
      options: {
        'domain': [0, 180],
        'range': DEFAULT_BI_BAR_RANGE
      }
    },
    'Gait/Joint/Neck/Rotation/Maximum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'neck_rotation_maximum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Neck/Rotation/Minimum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'neck_rotation_minimum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Neck/Rotation/ROM': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'neck_rotation_rom.svg',
      options: {
        'domain': [0, 180],
        'range': DEFAULT_BI_BAR_RANGE
      }
    },
    // Trunk
    'Gait/Joint/Trunk/Abduction/Maximum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'trunk_abduction_maximum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Trunk/Abduction/Minimum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'trunk_abduction_minimum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Trunk/Abduction/ROM': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'trunk_abduction_rom.svg',
      options: {
        'domain': [0, 100],
        'range': DEFAULT_BI_BAR_RANGE
      }
    },
    'Gait/Joint/Trunk/Flexion/Maximum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'trunk_flexion_maximum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Trunk/Flexion/Minimum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'trunk_flexion_minimum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Trunk/Flexion/ROM': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'trunk_flexion_rom.svg',
      options: {
        'domain': [0, 100],
        'range': DEFAULT_BI_BAR_RANGE
      }
    },
    'Gait/Joint/Trunk/Rotation/Maximum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'trunk_rotation_maximum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Trunk/Rotation/Minimum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'trunk_rotation_minimum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Trunk/Rotation/ROM': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'trunk_rotation_rom.svg',
      options: {
        'domain': [0, 180],
        'range': DEFAULT_BI_BAR_RANGE
      }
    },
    // Back
    'Gait/Joint/Back/Abduction/Maximum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'lumbar_abduction_maximum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Back/Abduction/Minimum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'lumbar_abduction_minimum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Back/Abduction/ROM': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'lumbar_abduction_rom.svg',
      options: {
        'domain': [0, 100],
        'range': DEFAULT_BI_BAR_RANGE
      }
    },
    'Gait/Joint/Back/Flexion/Maximum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'lumbar_flexion_maximum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Back/Flexion/Minimum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'lumbar_flexion_minimum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Back/Flexion/ROM': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'lumbar_flexion_rom.svg',
      options: {
        'domain': [0, 100],
        'range': DEFAULT_BI_BAR_RANGE
      }
    },
    'Gait/Joint/Back/Rotation/Maximum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'lumbar_rotation_maximum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Back/Rotation/Minimum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'lumbar_rotation_minimum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Back/Rotation/ROM': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'lumbar_rotation_rom.svg',
      options: {
        'domain': [0, 100],
        'range': DEFAULT_BI_BAR_RANGE
      }
    },
    // Clavicle
    'Gait/Joint/Clavicle/Abduction/Maximum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'clavicle_abduction_maximum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Clavicle/Abduction/Minimum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'clavicle_abduction_minimum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Clavicle/Abduction/ROM': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'clavicle_abduction_rom.svg',
      options: {
        'domain': [0, 75],
        'range': DEFAULT_BI_BAR_RANGE
      }
    },
    'Gait/Joint/Clavicle/Flexion/Maximum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'clavicle_flexion_maximum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Clavicle/Flexion/Minimum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'clavicle_flexion_minimum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Clavicle/Flexion/ROM': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'clavicle_flexion_rom.svg',
      options: {
        'domain': [0, 75],
        'range': DEFAULT_BI_BAR_RANGE
      }
    },
    'Gait/Joint/Clavicle/Rotation/Maximum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'clavicle_rotation_maximum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Clavicle/Rotation/Minimum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'clavicle_rotation_minimum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Clavicle/Rotation/ROM': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'clavicle_rotation_rom.svg',
      options: {
        'domain': [0, 100],
        'range': DEFAULT_BI_BAR_RANGE
      }
    },
    // Shoulder
    'Gait/Joint/Shoulder/Abduction/Maximum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'shoulder_abduction_maximum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Shoulder/Abduction/Minimum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'shoulder_abduction_minimum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Shoulder/Abduction/ROM': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'shoulder_abduction_rom.svg',
      options: {
        'domain': [0, 180],
        'range': DEFAULT_BI_BAR_RANGE
      }
    },
    'Gait/Joint/Shoulder/Flexion/Maximum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'shoulder_flexion_maximum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Shoulder/Flexion/Minimum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'shoulder_flexion_minimum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Shoulder/Flexion/ROM': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'shoulder_flexion_rom.svg',
      options: {
        'domain': [0, 180],
        'range': DEFAULT_BI_BAR_RANGE
      }
    },
    'Gait/Joint/Shoulder/Rotation/Maximum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'shoulder_rotation_maximum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Shoulder/Rotation/Minimum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'shoulder_rotation_minimum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Shoulder/Rotation/ROM': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'shoulder_rotation_rom.svg',
      options: {
        'domain': [0, 180],
        'range': DEFAULT_BI_BAR_RANGE
      }
    },
    // Elbow
    'Gait/Joint/Elbow/Flexion/Maximum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'elbow_flexion_maximum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Elbow/Flexion/Minimum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'elbow_flexion_minimum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Elbow/Flexion/ROM': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'elbow_flexion_rom.svg',
      options: {
        'domain': [0, 180],
        'range': DEFAULT_BI_BAR_RANGE
      }
    },
    'Gait/Joint/Elbow/Rotation/Maximum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'elbow_rotation_maximum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Elbow/Rotation/Minimum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'elbow_rotation_minimum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Elbow/Rotation/ROM': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'elbow_rotation_rom.svg',
      options: {
        'domain': [0, 180],
        'range': DEFAULT_BI_BAR_RANGE
      }
    },
    // Wrist
    'Gait/Joint/Wrist/Abduction/Maximum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'wrist_abduction_maximum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Wrist/Abduction/Minimum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'wrist_abduction_minimum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Wrist/Abduction/ROM': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'wrist_abduction_rom.svg',
      options: {
        'domain': [0, 100],
        'range': DEFAULT_BI_BAR_RANGE
      }
    },
    'Gait/Joint/Wrist/Flexion/Maximum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'wrist_flexion_maximum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Wrist/Flexion/Minimum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'wrist_flexion_minimum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Wrist/Flexion/ROM': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'wrist_flexion_rom.svg',
      options: {
        'domain': [0, 180],
        'range': DEFAULT_BI_BAR_RANGE
      }
    },
    // Hip
    'Gait/Joint/Hip/Abduction/Maximum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'hip_abduction_maximum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Hip/Abduction/Minimum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'hip_abduction_minimum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Hip/Abduction/ROM': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'hip_abduction_rom.svg',
      options: {
        'domain': [0, 180],
        'range': DEFAULT_BI_BAR_RANGE
      }
    },
    'Gait/Joint/Hip/Flexion/Maximum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'hip_flexion_maximum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Hip/Flexion/Minimum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'hip_flexion_minimum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Hip/Flexion/ROM': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'hip_flexion_rom.svg',
      options: {
        'domain': [0, 180],
        'range': DEFAULT_BI_BAR_RANGE
      }
    },
    'Gait/Joint/Hip/Rotation/Maximum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'hip_rotation_maximum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Hip/Rotation/Minimum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'hip_rotation_minimum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Hip/Rotation/ROM': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'hip_rotation_rom.svg',
      options: {
        'domain': [0, 180],
        'range': DEFAULT_BI_BAR_RANGE
      }
    },
    // Knee
    'Gait/Joint/Knee/Abduction/Maximum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'knee_abduction_maximum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Knee/Abduction/Minimum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'knee_abduction_minimum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Knee/Abduction/ROM': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'knee_abduction_rom.svg',
      options: {
        'domain': [0, 50],
        'range': DEFAULT_BI_BAR_RANGE
      }
    },
    'Gait/Joint/Knee/Flexion/Maximum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'knee_flexion_maximum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Knee/Flexion/Minimum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'knee_flexion_minimum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Knee/Flexion/ROM': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'knee_flexion_rom.svg',
      options: {
        'domain': [0, 180],
        'range': DEFAULT_BI_BAR_RANGE
      }
    },
    'Gait/Joint/Knee/Rotation/Maximum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'knee_rotation_maximum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Knee/Rotation/Minimum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'knee_rotation_minimum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Knee/Rotation/ROM': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'knee_rotation_rom.svg',
      options: {
        'domain': [0, 50],
        'range': DEFAULT_BI_BAR_RANGE
      }
    },
    // Ankle
    'Gait/Joint/Ankle/Abduction/Maximum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'ankle_rotation_maximum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Ankle/Abduction/Minimum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'ankle_rotation_minimum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Ankle/Abduction/ROM': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'ankle_rotation_rom.svg',
      options: {
        'domain': [0, 50],
        'range': DEFAULT_BI_BAR_RANGE
      }
    },
    'Gait/Joint/Ankle/Flexion/Maximum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'ankle_flexion_maximum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Ankle/Flexion/Minimum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'ankle_flexion_minimum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Ankle/Flexion/ROM': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'ankle_flexion_rom.svg',
      options: {
        'domain': [0, 100],
        'range': DEFAULT_BI_BAR_RANGE
      }
    },
    'Gait/Joint/Ankle/Rotation/Maximum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'ankle_abduction_maximum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Ankle/Rotation/Minimum': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormArcVis,
      baseSvg: MOBILITY_LAB_BASE + 'ankle_abduction_minimum.svg',
      options: {
        'offsetAngle': 0
      }
    },
    'Gait/Joint/Ankle/Rotation/ROM': {
      type: enums.metricVisType.APDM_VIS,
      visClass: BilateralOneNormBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'ankle_abduction_rom.svg',
      options: {
        'domain': [0, 100],
        'range': DEFAULT_BI_BAR_RANGE
      }
    },
    // mTBI specific metrics
    // Transverse
    'mTBI/Forehead Transverse ROM': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'mtbi/forehead_rom_transverse_vis.svg',
      options: {
        'domain': [0, 180],
        'range': DEFAULT_UNI_BAR_RANGE
      }
    },
    'mTBI/Forehead Transverse Maximum Velocity': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'mtbi/forehead_velocity_transverse_vis.svg',
      options: {
        'domain': [0, 400],
        'range': DEFAULT_UNI_BAR_RANGE
      }
    },
    'mTBI/Sternum Transverse ROM': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'mtbi/sternum_rom_transverse_vis.svg',
      options: {
        'domain': [0, 180],
        'range': DEFAULT_UNI_BAR_RANGE
      }
    },
    'mTBI/Sternum Transverse Maximum Velocity': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'mtbi/sternum_velocity_transverse_vis.svg',
      options: {
        'domain': [0, 100],
        'range': DEFAULT_UNI_BAR_RANGE
      }
    },
    // Sagittal
    'mTBI/Forehead Sagittal ROM': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'mtbi/forehead_rom_sagittal_vis.svg',
      options: {
        'domain': [0, 180],
        'range': DEFAULT_UNI_BAR_RANGE
      }
    },
    'mTBI/Forehead Sagittal Maximum Velocity': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'mtbi/forehead_velocity_sagittal_vis.svg',
      options: {
        'domain': [0, 400],
        'range': DEFAULT_UNI_BAR_RANGE
      }
    },
    'mTBI/Sternum Sagittal ROM': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'mtbi/sternum_rom_sagittal_vis.svg',
      options: {
        'domain': [0, 180],
        'range': DEFAULT_UNI_BAR_RANGE
      }
    },
    'mTBI/Sternum Sagittal Maximum Velocity': {
      type: enums.metricVisType.APDM_VIS,
      visClass: UnilateralBarVis,
      baseSvg: MOBILITY_LAB_BASE + 'mtbi/sternum_velocity_sagittal_vis.svg',
      options: {
        'domain': [0, 100],
        'range': DEFAULT_UNI_BAR_RANGE
      }
    }
  };
});
//# sourceMappingURL=metric_vis_map.js.map
