"use strict";

/* Copyright (c) 2017-2019, APDM Inc.
 *
 * report_container.js
 *
 * Module to handle build single and sequence reports
 */
define(['jquery', 'd3', 'utils', 'server_handler', 'crossroads', 'hasher', 'model_protocol', 'error_handler', 'session', 'app/user_options_handler', 'app/ui_state', 'app/dialog_in_series', 'app/report_enums', 'app/license_handler', 'app/mc_report_handler', 'app/joint_angle_report_handler', 'metric_definition_helper', 'app/metric_selection_helper', 'app/delete_handler', 'app/reassign_trial', 'app/edit_trial_type', 'app/joint_angle_strip_plots', 'app/joint_angle_variability_plots', 'app/upload_handler', 'model_dispatcher', 'res_req_map', 'support_upload', 'app/trial_notes', 'time_based_controller'], function ($, d3, utils, ServerHandler, crossroads, hasher, ModelProtocol, ErrorHandler, Session, UserOptionsHandler, uiState, DialogInSeries, reportEnums, LicenseHandler, ReportHandler, JointAngleReportHandler, MetricDefinitionHelper, MetricSelectionHelper, deleteHandler, reassignTrial, editTrialType, JointAngleStripPlots, jointAngleVariabilityPlots, UploadHandler, ModelDispatcher, ResReqMap, supportUpload, trialNotes, TimeBasedController) {
  var _backdrop;

  var _isPreview = false;

  var _dialog;

  var _subject;

  var _jointAnglePlot;
  /**
   * Create a report dialog for just a single trial.
   * @param {Subject} subject The subject associated with trial.
   * @param {Trial} trial The trial to display.
   */


  function singleTrialReport(subject, trial, showBackdrop) {
    TimeBasedController.getInstance().dispose();
    _isPreview = false;
    hasher.setHash('report');
    trialReport(subject, trial, showBackdrop);
  }
  /**
   * Build a report for a single trial.
   * @param {Subject} subject The subject associated with trial.
   * @param {Trial} trial The trial to display.
   */


  function trialReport(subject, trial, showBackdrop) {
    _subject = subject;
    _backdrop = showBackdrop ? showBackdrop : true;
    ServerHandler.getInstance().postUIState(uiState.READING_RESULTS); // Setup the modal dialog for reports

    _dialog = new DialogInSeries('dialog-report');
    $('#dialog-report-title').text('Subject: ' + UserOptionsHandler.getInstance().getSubjectName(_subject));
    var filterType = reportEnums.filterType.ALL;

    if (trial instanceof Session || trial.getSequence()) {
      filterType = reportEnums.filterType.SEQUENCE;
    }

    buildReport('#dialog-report-body', trial, filterType); // Open the dialog.

    _dialog.show(_backdrop); // Set the close handler


    $('.dialog-report-close').off('click').on('click', function () {
      if (_isPreview) {
        _dialog.hide(false);
      } else {
        _dialog.hide(true); // If we're not displaying a backdrop then the report
        // is being displayed in after running tests. If study
        // has HttpBackupSetting, allow uploading trials now.


        if (!showBackdrop && UserOptionsHandler.getInstance().getUploadAfterSequence()) {
          UploadHandler.getInstance().uploadTrials();
        }
      }
    }); // $('#switchable')
    //     .load('/mobility_clinic/html/subject_reports.html', pageLoaded);
    // function pageLoaded() {
    //     // Setup the modal dialog for reports
    //     $('#subject-report-title')
    //         .text(UserOptionsHandler.getInstance()
    //               .getSubjectName(_subject));
    //     var filterType = reportEnums.filterType.ALL;
    //     if (trial instanceof Session || trial.getSequence()) {
    //         filterType = reportEnums.filterType.SEQUENCE;
    //     }
    //     addNavigationHandlers();
    //     buildReport('#subject-report-body', trial, filterType);
    // }
    // }
    // function addNavigationHandlers() {
    //     if (_isPreview) {
    //         return;
    //     }
    //     // Back to subject button.
    //     var backBtn = d3.select('#report-back-to-subject-button');
    //     backBtn.on('click', null);
    //     backBtn.on('click', function() {
    //         var objId = _subject.getObjId();
    //         crossroads.parse('dispatch/subject?id=' + objId.getId() +
    //                          '&localId=' + objId.getLocalId());
    //     });
  }
  /**
   * Open a report container for a series for trials.
   * @param {Subject} subject The subject associated with this trial.
   * @param {Array} trials Array of trials to display in report.
   * @param {reportEnum.filterType} filterType Filter that should be used
   * on comparision trial set.
   */


  function multipleTrialReport(subject, trials, filterType, showBackdrop) {
    TimeBasedController.getInstance().dispose();
    _isPreview = false;
    _subject = subject;
    hasher.setHash('report');
    _backdrop = showBackdrop ? showBackdrop : true;
    _dialog = new DialogInSeries('dialog-report');
    $('#dialog-report-title').text('Subject: ' + UserOptionsHandler.getInstance().getSubjectName(_subject));
    $('#dialog-report-body').empty();
    $('#dialog-report-body').load('/mobility_clinic/html/test_series_results.html', pageLoaded); // Set the close handler

    $('.dialog-report-close').off('click').on('click', function () {
      _dialog.hide(true); // If we're not displaying a backdrop then the report
      // is being displayed in after running tests. If study
      // has HttpBackupSetting, allow uploading trials now.


      if (!showBackdrop && UserOptionsHandler.getInstance().getUploadAfterSequence()) {
        UploadHandler.getInstance().uploadTrials();
      }
    }); // $('#switchable')
    //     .load('/mobility_clinic/html/subject_reports.html', pageLoaded);

    function pageLoaded() {
      //     $('#subject-report-title')
      //         .text('Subject: ' + UserOptionsHandler.getInstance()
      //               .getSubjectName(_subject));
      //     $('#subject-report-body')
      //         .load('/mobility_clinic/html/test_series_results.html',
      //               testSeriesPageLoaded);
      // }
      // function testSeriesPageLoaded() {
      var trialsByType = {};
      trials.forEach(function (d) {
        if (trialsByType[d.getTestName()]) {
          trialsByType[d.getTestName()].push(d);
        } else {
          trialsByType[d.getTestName()] = [d];
        }
      });
      buildSeriesReportTabs(_dialog, trials, filterType);

      _dialog.show(_backdrop);
    }
  }
  /**
   * Open up a report in "Preview Mode", which removes the
   * "gear" menu and the ability to switch between trials.
   * @param {Subject} subject The trial's subject.
   * @param {Trial} trial The trial to display.
   */


  function singleTrialPreview(subject, trial) {
    _isPreview = true; // Need to refresh the current subject before we can open
    // the report preview.

    var url = 'refreshedForPreview';
    var openPreviewRoute = crossroads.addRoute(url, function () {
      crossroads.removeRoute(openPreviewRoute);
      trialReport(ModelDispatcher.getInstance().getCurrentSubject(), trial, false);
    });
    var requestData = {};
    requestData.id = subject.getObjId().getId();
    requestData.localId = subject.getObjId().getLocalId();
    requestData.url = url;
    crossroads.parse('dispatch/refreshSubject/' + ResReqMap.getInstance().setRequestData(requestData));
  }
  /**
   * Build the tabs for each different test type given in the trials.
   * @param {DialogInSeries} dialog The dialog the reports are being opened in.
   * @param {Array} trials The trials to get test types from.
   * @param {reportEnums.filterType} filterType The filter to use in the
   * comparison view.
   */


  function buildSeriesReportTabs(dialog, trials, filterType) {
    // Group trials by type.
    var trialsByType = {};
    trials.forEach(function (d) {
      if (trialsByType[d.getTestName()]) {
        trialsByType[d.getTestName()].push(d);
      } else {
        trialsByType[d.getTestName()] = [d];
      }
    }); // Build tabs for each of the test types

    var div = d3.select('#series-test-tabs');
    var tabList = div.append('ul').attr('id', 'series-tab-list');
    var tabDiv = div.append('div').attr('class', 'tab-content');
    var tabs = [];
    tabList.selectAll('li').data(Object.keys(trialsByType)).enter().append('li').each(function (d, i) {
      var id = utils.makeHtmlId(d) + '-' + i;
      d3.select(this).append('a').attr('href', '#' + id).attr('data-toggle', 'tab').text(d);
      var reportDiv = tabDiv.append('div').attr('id', id).attr('class', 'tab-pane');
      reportDiv.append('div').attr('class', 'report_vis_div');
      var tableDiv = reportDiv.append('div').attr('class', 'report_table_div'); // Need to handle trials and test sequence sessions
      // differently

      var curTrial = trialsByType[d][0];
      tabs.push({
        reportDiv: reportDiv,
        trial: curTrial
      });
      tableDiv.style('width', '100%');
    }); // Set handler to metric group select dropdown.

    var reportDiv = d3.select('#dialog-report-body');
    reportDiv.select('#report-subject-name').text(UserOptionsHandler.getInstance().getSubjectName(_subject)); // Build the content for the different tabs

    tabs.forEach(function (d) {
      d.report = buildReport('#' + d.reportDiv.attr('id'), d.trial, filterType);
    }); // Update the tables when they become visible. Need to wait for
    // loading to be complete. Once the last is done, update title
    // with the first tab's report.

    var completedTabs = 0;
    tabs.forEach(function (d) {
      $(d.reportDiv.node()).on('buildReport.complete', function () {
        if (completedTabs === tabs.length - 1) {
          tabs[0].report.updateTrialTitle();
        }

        completedTabs++;
        var ref = $('a[href="#' + d.reportDiv.attr('id') + '"]');
        ref.on('shown.bs.tab', function () {
          d.report.update();
        });
      });
    });
    tabList.attr('class', 'nav nav-tabs');
    $('#series-tab-list a:first').tab('show');
  }
  /**
   * Build a report for a trial, or a comparsion group of trials.
   * Also sets up the menus and selections in the report.
   * @param {String} containerId The id for the dialog.
   * @param {Trial} trial The current trial to view.
   * @param {reportEnums.filterType} filterType The filter to
   * use in comparison view.
   * @return The report instance.
   */


  function buildReport(containerId, trial, filterType) {
    var report;

    if (trial.getTestName() === 'Free Form') {
      report = doJointAngleReport(containerId, trial, filterType);
    } else {
      report = doStandardReport(containerId, trial, filterType);
    }

    return report;
  }
  /**
   * Create the standard report for the standard trials.
   * @param {String} containerId The id for the dialog.
   * @param {Trial} trial The current trial to view.
   * @param {reportEnums.filterType} filterType The filter to
   * use in comparison view.
   * @return The report instance.
   */


  function doStandardReport(containerId, trial, filterType) {
    var report = new ReportHandler(trial);
    $(containerId).empty();
    $(containerId).load('/mobility_clinic/html/test_results.html', pageLoaded);
    var container = d3.select(containerId);

    function pageLoaded() {
      // Remove fade if IE
      if (utils.isIE()) {
        $('.modal').removeClass('fade');
      }

      report.currentSubject(_subject).currentTrial(trial).reportContainer(container).update();
      jointAngleButtonHandlers(container, report);
      exportButtonHandlers(container, report);
      buildFilterSubmenu(report, container, filterType);

      if (_isPreview === true) {
        // Now hide all the UI elements that we don't want visible.
        $('#report-options-button').css('display', 'none');
        $('.next-prev-container').css('display', 'none'); // Remove the "next/prev" test keyboard handlers.

        $(window).off('keydown.' + trial.getTestName);
      } else {
        addReportMenuHandlers(container, report);
      }
    }

    return report;
  }
  /**
   * Create the report for the "Free Form" joint angle test.
   * @param {String} containerId The id for the dialog.
   * @param {Trial} trial The current trial to view.
   * @param {reportEnums.filterType} filterType The filter to
   * use in comparison view.
   * @return The report instance.
   */


  function doJointAngleReport(containerId, trial, filterType) {
    var container = d3.select(containerId);
    var report = new JointAngleReportHandler(container, _subject, trial, filterType);
    $(container.node()).empty();
    $(container.node()).load('/mobility_kinematics/html/joint_angle_report.html', pageLoaded);

    function pageLoaded() {
      // Remove fade if IE
      if (utils.isIE()) {
        $('.modal').removeClass('fade');
      }

      report.update();
      buildFilterSubmenu(report, container, filterType);
      exportButtonHandlers(container, report);
      jointAngleButtonHandlers(container, report);

      if (_isPreview === true) {
        // Now hide all the UI elements that we don't want visible.
        $('#report-options-button').css('display', 'none');
        $('.next-prev-container').css('display', 'none'); // Remove the "next/prev" test keyboard handlers.

        $(window).off('keydown.' + trial.getTestName);
      } else {
        addReportMenuHandlers(container, report);
      } // Add the notes


      trialNotes.init(trial, container);
    }

    return report;
  }
  /**
   * Add the handlers to the items in the gear menu.
   * @param {d3.selection} container The container holding the menu.
   * @param {ReportHandler} report The report instance.
   */


  function addReportMenuHandlers(container, report) {
    // Remove menu options that aren't valid for Mobility Web
    if (ServerHandler.getInstance().hasJsPostHandler()) {
      $('.rcp-only').remove();
    } // Add the handler for the "Delete button" after checking
    // permissions.


    ModelDispatcher.getInstance().checkPermissions('delete', report.currentTrial().getObjId()).then(function (d) {
      if (d.hasPermission) {
        container.select('#report-delete-trial-button').on('click', function () {
          var trial = report.currentTrial();
          deleteHandler.deleteTest(trial, function () {
            var objId = _subject.getObjId();

            var subjectUrl = 'subject?id=' + objId.getId() + '&localId=' + objId.getLocalId();
            crossroads.parse('dispatch/' + subjectUrl);
            crossroads.parse(subjectUrl);

            _dialog.hide(true);
          });
        });
      } else {
        container.select('#report-delete-trial-button').style('color', '#9d9d9d').style('cursor', 'not-allowed').style('pointer-events', 'none');
      }
    }, function (e) {
      ErrorHandler.showError(e.error().statusText);
    }); // Attach handler to print button

    container.select('#report-print-button').on('click', function () {
      loadPrintPreview(report);
    }); // Attach handler to edit metric groups

    container.select('#metric-group-edit-button').on('click', function () {
      metricSelectDialog(report);
    }); // Add handlers to reassign trial and edit trial type after
    // checking permissions

    ModelDispatcher.getInstance().checkPermissions('edit', report.currentTrial().getObjId()).then(function (d) {
      if (d.hasPermission) {
        container.select('#reassign-trial-button').on('click', function () {
          reassignTrial.open(report.currentTrial(), _subject);
        }); // Edit the trial type or condition.

        container.select('#edit-trial-type-button').on('click', function () {
          editTrialType.open(report.currentTrial());
        });
      } else {
        container.select('#reassign-trial-button').style('color', '#9d9d9d').style('cursor', 'not-allowed').style('pointer-events', 'none');
        container.select('#edit-trial-type-button').style('color', '#9d9d9d').style('cursor', 'not-allowed').style('pointer-events', 'none');
      }
    }); // Trigger an event to let anyone know that the report is loaded.

    $(container.node()).trigger('buildReport.complete'); // Open up the raw data plot.

    container.select('#raw-data-plot-button').on('click', function () {
      // FIXME: Not the ideal solution. Need a better way to
      // get the video file info if it exists. This should
      // change when video becomes "just another" report
      // component.
      var trial = report.currentTrial();
      var objId = trial.getObjId();
      ServerHandler.getInstance().post({
        type: ModelProtocol.get_video_metadata,
        fileName: trial.getDataFileName()
      }, 'json', function (d) {
        var url = '/mobility_clinic/html/' + 'mobilitylab_raw_data_view.html?type=rawdata' + '&id=' + objId.getId() + '&localId=' + objId.getLocalId();

        if (d.available === true) {
          url = url + '&video=' + d.videoAndMetadataPath;
        }

        window.open(url);
      }, function (d) {
        ErrorHandler.showError(d.error().statusText);
      });
    }); // Export the visualization as png.
    // FIXME: For now, remove this if we are running on Windows.

    var exportVisBtn = container.select('#export-vis-button');

    if (utils.isIE()) {
      exportVisBtn.remove();
    } else {
      exportVisBtn.on('click', function () {
        report.exportVisAsPng();
      });
    } // Export the visualization as SVG.


    container.select('#export-vis-as-svg-button').on('click', function () {
      report.exportVisAsSvg();
    });
  }
  /**
   * Add handlers, or remove the buttons for displaying
   * joint angle plots.
   * TODO: These should be better intergrated into report.
   * @param {jQuery.selection} container The report's container.
   * @param {ReportHandler} report The report being displayed.
   */


  function jointAngleButtonHandlers(container, report) {
    if (!LicenseHandler.getInstance().isKinematics() || report.currentTrial().getTestName() !== 'MLK Walk' && report.currentTrial().getTestName() !== 'Free Form') {
      container.selectAll('.mobility-kinematics').style('display', 'none');
    } else {
      var jointAngleBtn = container.select('#joint-angle-plot-button');
      jointAngleBtn.style('display', null).on('click', function () {
        var joints = UserOptionsHandler.getInstance().getPlottedJointAngles();
        _jointAnglePlot = new JointAngleStripPlots();

        _jointAnglePlot.open(report.currentTrial(), joints);
      });
      container.select('#joint-angle-variability-plot-button').on('click', function () {
        jointAngleVariabilityPlots.open(report.currentTrial());
      });
      container.select('#joint-angle-bvh-export-button').on('click', function () {
        ServerHandler.getInstance().post({
          type: ModelProtocol.export_joint_angles_to_bvh,
          analysisFile: report.currentTrial().getAnalysisFileName()
        }, null, null, null);
      });
      container.select('#joint-angle-static-animation-button').on('click', function () {
        report.displayStaticAnimation();
      });

      if (report.currentTrial().getTestName() === 'Free Form') {
        jointAngleBtn.style('display', 'none');
        container.select('#joint-angle-variability-plot-button').style('display', 'none');
      }
    }
  }
  /**
   * Add handlers to the various data export buttons in "gear" dropdown.
   * @param {jQuery.selection} container The report's container.
   * @param {ReportHandler} report The report being displayed.
   */


  function exportButtonHandlers(container, report) {
    if (!LicenseHandler.getInstance().isResearchView()) {
      container.selectAll('.csv-export-option').remove();
    }

    container.select('#export-trial-button').on('click', function () {
      var key = ResReqMap.getInstance().setRequestData(report.currentTrial().getObjId());
      crossroads.parse('dispatch/exportToCsv/trial/' + key);
    });
    container.select('#export-trials-of-type-button').on('click', function () {
      var key = ResReqMap.getInstance().setRequestData(report.currentTrial().getObjId());
      crossroads.parse('dispatch/exportToCsv/trials_of_this_type/' + key);
    }); // Upload the log and the trial data

    container.select('#upload-log-button').on('click', function () {
      supportUpload.openLogAndTrial(report.currentTrial());
    });
  }
  /**
   * Build the submenu for the trial filter.
   * @param {Object} report The report being filtered.
   * @param {d3.selection} container The container holding the menu.
   * @param {reportEnums.filterType} filterType The filter
   *  to use in comparison view.
   */


  function buildFilterSubmenu(report, container, filterType) {
    var labels = [{
      text: 'Show All',
      type: reportEnums.filterType.ALL
    }, {
      text: 'By Current Condition',
      type: reportEnums.filterType.CONDITION
    }, {
      text: 'By Current Sequence',
      type: reportEnums.filterType.SEQUENCE
    }, {
      text: 'By Current Day',
      type: reportEnums.filterType.DAY
    }];
    var listItems = container.select('#filter-select-submenu').selectAll('li.metric-group-list-item').data(labels, function (d) {
      return d.type;
    });
    listItems.enter().append('li').append('a').text(function (d) {
      return d.text;
    }).attr('class', 'metric-group-list-item').attr('href', function (d) {
      return '#' + utils.makeHtmlId(d.text);
    }).attr('value', function (d) {
      return d.type;
    }).on('click', function (d) {
      report.comparisonFilter(d.type);
      updateFilterState(report, container);
    });
    report.comparisonFilter(filterType);
    updateFilterState(report, container);
  }
  /**
   * Update the marked selection in the filter submenu.
   * @param {Object} report The report that is being filtered.
   * @param {d3.selection} container The menu's enclosing container.
   */


  function updateFilterState(report, container) {
    // Update the check next to the current selection
    var listItems = container.select('#filter-select-submenu').selectAll('li');
    listItems.selectAll('span').remove();
    listItems.each(function (d) {
      // Check and see if 'Sequence' option is vaild.
      if (d.type === reportEnums.filterType.SEQUENCE) {
        if (!(report.currentTrial() instanceof Session) && !report.currentTrial().getSequence()) {
          d3.select(this).classed('disabled', true);
        } else {
          d3.select(this).classed('disabled', false);
        }
      }

      if (report.comparisonFilter() === d.type) {
        d3.select(this).select('a').append('span').attr('class', 'iconic iconic-check');
      }
    });
  }
  /**
   * Load the print preview pane, drawing the report.
   * @param report The report handler instance.
   */


  function loadPrintPreview(report) {
    var server = ServerHandler.getInstance();
    var container = report.reportContainer();
    var notes = report.currentTrial().getNotes();

    if (!notes) {
      notes = ' ';
    }

    var requestData = {
      type: ModelProtocol.print_page,
      subjectTitle: UserOptionsHandler.getInstance().getSubjectName(_subject),
      trialTitle: d3.select('#report-title').text(),
      visDiv: container.select('.report_vis_div').html(),
      notes: notes
    };

    if (report.currentTrial().getTestName() !== 'Free Form') {
      requestData.tableDiv = container.select('.report_table_div').html();
    } // If this is a web instance, handle printing with the browser.


    if (server.hasJsPostHandler()) {
      printFromWeb(requestData);
      return;
    }

    server.post(requestData, null, null, null);
  }

  function printFromWeb(requestData) {
    var printWindow;

    if (LicenseHandler.getInstance().isKinematics()) {
      printWindow = window.open('/mobility_kinematics/html/test_results_print.html');
    } else {
      printWindow = window.open('/mobility_clinic/html/test_results_print.html');
    }

    printWindow.onload = function () {
      var doc = $(printWindow.document);
      doc.find('#print-report-subject-name').html(requestData.subjectTitle);
      doc.find('#print-report-vis-div').html(requestData.visDiv);
      doc.find('#print-report-table-div').html(requestData.tableDiv);
      doc.find('#print-report-trial-notes').html(requestData.notes);
      doc.find('#close-print-preview-button').click(function () {
        printWindow.close();
      });
      doc.find('#print-report-button').click(function () {
        printWindow.print();
      });
    };
  }
  /**
   * Create the tabs and tables for the selection of which metrics to display.
   * @param {mcReportHandler} report The report to update when dialog closes.
   */


  function metricSelectDialog(report) {
    var dialog = $('#dialog-options');
    $('#dialog-options-body').load('/mobility_clinic/html/metric_select.html', pageLoaded);

    function pageLoaded() {
      // Build tabs when modal is visible.
      dialog.one('shown.bs.modal', function () {
        MetricSelectionHelper.getInstance().buildMetricTabs('#configure-metrics-dialog', true, report.currentTrial().getTestName());
      }); // Send a notification that the metric groups have been
      // updated with the dialog closes.

      dialog.one('hide.bs.modal', function () {
        report.getDispatcher().call('metricGroupChange');
      });
      dialog.modal();
    }
  }

  return {
    singleTrialReport: singleTrialReport,
    multipleTrialReport: multipleTrialReport,
    singleTrialPreview: singleTrialPreview
  };
});
//# sourceMappingURL=report_container.js.map
