"use strict";

/* Copyright (c) 2018 APDM, Inc.
 *
 * single_user_handler.js
 *
 * Does the check to see if the current user is a member of the
 * current study and if their role is a single user role.
 */
define(['model_dispatcher', 'app/exchange_handler', 'utils'], function (ModelDispatcher, ExchangeHandler, utils) {
  'use strict';

  var _instance;

  var _isSingleUser;
  /**
   * Role names that are associated with the single user UI.
   */


  var SINGLE_USER_ROLES = ['mtbi_study_subject'];
  /**
   * Initialize this singleton. Default the isSingleUser flag to
   * false if we don't have a study yet.
   */

  function init() {
    _isSingleUser = false;
    /**
     * The being viewed has changed or updated. Update the single
     * user flag.
     */

    function studyWasUpdated() {
      var study = ModelDispatcher.getInstance().getCurrentStudy();

      if (study === null) {
        _isSingleUser = false;
      }

      var memberships = study.getStudyMemberships();

      if (!memberships || !memberships.length) {
        return;
      } // Find the user in the study memberships.


      var currentUser = ExchangeHandler.getInstance().getCurrentUser();
      var users = memberships.filter(function (d) {
        return d.mobilityLabUser.id === currentUser.id && d.mobilityLabUser.localId === currentUser.localId;
      });

      if (!users.length) {
        return;
      } else if (users.length > 1) {
        utils.error('More than one study membership associated with ' + 'current user.');
        return;
      }

      if (users[0].roles && users[0].roles.name && SINGLE_USER_ROLES.indexOf(users[0].roles.name) > -1) {
        _isSingleUser = true;
      }
    }

    return {
      /**
       * Study has changed or be updated, check the user and the
       * roles again.
       */
      studyUpdated: function studyUpdated() {
        studyWasUpdated();
      },

      /**
       * Returns true if we should have a single user UI.
       * @return {Boolean} True if UI should be limited to a
       * single user/subject.
       */
      isSingleUserUI: function isSingleUserUI() {
        return _isSingleUser;
      }
    };
  }

  return {
    getInstance: function getInstance() {
      if (!_instance) {
        _instance = init();
      }

      return _instance;
    }
  };
});
//# sourceMappingURL=single_user_handler.js.map
