"use strict";

/* Copyright (c) 2016-2018, APDM Inc.
 *
 * trial_from_recording.js
 *
 * Dialog for creating a trial for a subject from a
 * raw recording.
 */
define(['jquery', 'd3', 'crossroads', 'bootstrap-dialog', 'utils', 'model_protocol', 'res_req_map', 'subject', 'server_handler', 'test_definition_handler', 'error_handler'], function ($, d3, crossroads, BootstrapDialog, utils, ModelProtocol, ResReqMap, Subject, ServerHandler, TestDefinitionHandler, ErrorHandler) {
  var dialog;
  var trialSelect;
  var conditionSelect;
  var localFileRoute;
  var subject; // NOTE: Need crossroad module available globally, so can be called by
  // server code.

  window.crossroads = crossroads;
  /**
   * Build and display the dialog.
   * @param {Subject} assignSubject The subject to assign the trial
   * too.
   */

  function initDialog(assignSubject) {
    subject = assignSubject;
    localFileRoute = crossroads.addRoute('message/FILE/{key}', function (key) {
      var response = ResReqMap.getInstance().getResponseData(key);
      $('#trial-from-recording-filename').val(response.filename);

      if (response.filename !== '') {
        $('#create-trial-button').attr('disabled', null);
      }
    });
    dialog = new BootstrapDialog({
      title: 'Create trial from raw recording',
      message: $('<div></div>').load('/mobility_clinic/html/trial_from_recording.html', function () {
        dialog.open();
      }),
      buttons: [{
        icon: 'iconic iconic-x',
        label: 'Cancel',
        cssClass: 'btn-link',
        action: function action(dialog) {
          dialog.close();
        }
      }, {
        id: 'create-trial-button',
        icon: 'iconic iconic-data-transfer-download',
        label: 'Create',
        cssClass: 'btn-success',
        action: function action() {
          createTrial();
        }
      }],
      onshown: dialogShown,
      onhide: function onhide() {
        crossroads.removeRoute(localFileRoute);
      }
    });
  }
  /**
   * Set handlers and selection options once the dialog is shown.
   */


  function dialogShown() {
    d3.select('#create-trial-button').attr('disabled', 'disabled');
    trialSelect = $('#trial-from-recording-test-select');
    d3.select(trialSelect.get(0)).selectAll('option').data(TestDefinitionHandler.getInstance().getTestNameMap()).enter().append('option').text(function (d) {
      return d.displayName;
    }).attr('value', function (d) {
      return d.name;
    });
    trialSelect.selectpicker('refresh');
    trialSelect.change(function () {
      updateConditionSelect();
    });
    conditionSelect = $('#trial-from-recording-condition-select');
    updateConditionSelect();
    $('#trial-from-recording-search-button').click(function () {
      ServerHandler.getInstance().post({
        type: ModelProtocol.get_local_filename
      }, null, null, function (d) {
        ErrorHandler.showError(d.error().statusText);
      });
    });
    $('#trial-from-recording-filename').on('keyup', function () {
      if ($(this).val() !== '') {
        $('#create-trial-button').attr('disabled', null);
      } else {
        $('#create-trial-button').attr('disabled', 'disabled');
      }
    });
  }
  /**
   * Test selection dropdown has changed, updates the condition
   * dropdown.
   */


  function updateConditionSelect() {
    var testName = trialSelect.val();
    var options = d3.select(conditionSelect.get(0)).selectAll('option').data(TestDefinitionHandler.getInstance().getTestConditionDefinitions(testName), function (d) {
      return d.conditionName;
    });
    options.enter().append('option').text(function (d) {
      return d.conditionDisplayName;
    }).attr('value', function (d) {
      return d.conditionName;
    });
    options.exit().remove();
    conditionSelect.selectpicker('refresh');
  }
  /**
   * Make the server call to create the trial from given recording.
   */


  function createTrial() {
    var objId = subject.getObjId();
    var key = ResReqMap.getInstance().setRequestData({
      filename: $('#trial-from-recording-filename').val(),
      testName: trialSelect.val(),
      conditionName: conditionSelect.val(),
      subjectId: objId.getId(),
      subjectLocalId: objId.getLocalId()
    });
    crossroads.parse('dispatch/createTrialFromRecording/' + key);
    dialog.close();
  }

  return {
    open: initDialog
  };
});
//# sourceMappingURL=trial_from_recording.js.map
