"use strict";

/* Copyright © 2015-2016 APDM, Inc.
 *
 * unilateral_numeric_vis.js
 */
define(['jquery', 'd3', 'app/apdm_vis'], function ($, d3, ApdmVis) {
  'use strict';
  /**
   * Set ApdmVis as base class.
   */

  UnilateralNumericVis.prototype = new ApdmVis();
  /**
   * Constructor for UnilateralNumericVis.
   * @param {d3.selection} container The d3 container to build
   * visualization in.
   * @param {String} baseSvg File name of the SVG to use for
   * visualization.
   * @param {String} testName The name of the test.
   * @param {String} conditionName The condition of the test.
   * @param {String} metricName The name of the metric.
   * @param {String} metrics The set of metrics for the current test.
   */

  function UnilateralNumericVis(container, baseSvg, testName, conditionName, metricName, metrics) {
    ApdmVis.call(this, container, baseSvg, testName, conditionName, metricName, metrics);
    this.scale = d3.scaleLinear();
    this.scale.range([0, Math.PI]);
    this.normRadius = 101;
    this.subjectRadius = 147; // Size of the cirlcles.

    this.meanCircRad = 10;
    this.rangeCircRad = 3; // Offset so that '0' will always be horizontal left.

    this.offset = -90;
  }
  /**
   * Update the plot.
   */


  UnilateralNumericVis.prototype.update = function () {
    var self = this;
    $(self.container.node()).load('../res/' + self.baseSvg, baseLoaded);

    function baseLoaded() {
      self.container.select('svg').attr({
        'width': 700,
        'height': 260
      });
      var visData = self.getUnilateralData();

      if (visData && visData.mean) {
        self.container.select('#unilateral-numeric-subject').text(visData.mean.toFixed(1));
      }
    }
  };

  return UnilateralNumericVis;
});
//# sourceMappingURL=unilateral_numeric_vis.js.map
