/* Copyright (c) 2017-2019, APDM Inc.
 *
 * edit_trial_type.js
 *
 * Dialog for editing a trial's test type and condition.
 */

define(['jquery', 'd3', 'crossroads', 'bootstrap-dialog', 'utils',
        'model_protocol', 'res_req_map', 'trial', 'server_handler',
        'test_definition_handler'],
       function ($, d3, crossroads, BootstrapDialog, utils, ModelProtocol,
                 ResReqMap, Trial, ServerHandler, TestDefinitionHandler)
{

    var _dialog;
    var _trial;
    var _trialSelect;
    var _conditionSelect;

    // NOTE: Need crossroad module available globally, so can be called by
    // server code.
    window.crossroads = crossroads;

    /**
     * Build and display the dialog.
     * @param {Trial} trial The trial to edit.
     */
    function initDialog(trial) {
        _trial = trial;
        _dialog = new BootstrapDialog({
            id: 'edit-trial-type-dialog',
            title: 'Edit trial test type and condition',
            message: $('<div></div>')
                .load('/mobility_clinic/html/edit_trial_type.html',
                      function() {_dialog.open(); }),
            buttons: [
                {
                    icon: 'iconic iconic-x',
                    label: 'Cancel',
                    cssClass: 'btn-link',
                    action: function(dialog) {
                        dialog.close();
                    }
                },
                {
                    id: 'edit-trial-type-continue-button',
                    icon: 'iconic iconic-check',
                    label: 'Continue',
                    cssClass: 'btn-success',
                    action: function() {
                        editTrial();
                    }
                }],
            onshown: dialogShown
        });
    }

    /**
     * Set handlers and selection options once the dialog is shown.
     */
    function dialogShown() {
        _trialSelect = $('#edit-trial-test-select');
        d3.select(_trialSelect.get(0)).selectAll('option')
            .data(TestDefinitionHandler.getInstance().getTestNameMap())
            .enter()
            .append('option')
            .text(function(d) { return d.displayName; })
            .attr('value', function(d) { return d.name; });
        _trialSelect.selectpicker('refresh');
        _trialSelect.change(function() {
            updateConditionSelect();
        });

        _conditionSelect = $('#edit-trial-condition-select');
        updateConditionSelect();
    }

    /**
     * Test selection dropdown has changed, updates the condition
     * dropdown.
     */
    function updateConditionSelect() {
        var testName = _trialSelect.val();
        var options = d3.select(_conditionSelect.get(0)).selectAll('option')
            .data(TestDefinitionHandler.getInstance()
                  .getTestConditionDefinitions(testName),
                  function(d) { return d.conditionName; });
        options.enter()
            .append('option')
            .text(function(d) { return d.conditionDisplayName; })
            .attr('value', function(d) { return d.conditionName; });
        options.exit().remove();
        _conditionSelect.selectpicker('refresh');
    }

    /**
     * Make the server call to change the trial test type and
     * condition.
     */
    function editTrial() {
        var objId = _trial.getObjId();
        var key = ResReqMap.getInstance().setRequestData({
            testName: _trialSelect.val(),
            conditionName: _conditionSelect.val(),
            trialId: objId.getId(),
            trialLocalId: objId.getLocalId()
        });
        crossroads.parse('dispatch/editTrialType/' + key);
        _dialog.close();
    }

    return {
        open: initDialog
    };
});
