/* Copyright (c) 2015-2017 APDM, Inc.
 *
 * license_handler.js
 *
 */

define(['server_handler', 'model_protocol', 'error_handler',
        'crossroads'],
       function (ServerHandler, ModelProtocol, ErrorHandler,
                 crossroads)
 {
    'use strict';
    var instance;

    var RESEARCH_FEATURE = 'MOBILITY_LAB_V2_RESEARCH';
    var KINEMATICS_FEATURE = 'MOBILITY_LAB_KINEMATICS';

    function init() {
        var featureList = [];
        var updateAvailable = false;

        // Initial update
        updateLicenseData();

        function updateLicenseData() {
            ServerHandler.getInstance().post(
                {
                    type: ModelProtocol.get_license_data
                },
                'json',
                function(d) {
                    featureList = d.featureList;
                    updateAvailable = d.updateAvailable;
                    crossroads.parse('licenseDataUpdated');
                },
                function(d) {
                    ErrorHandler.showError(d.error().statusText);
                }
            );
        }

        return {
            /**
             * Update the license data.
             */
            update: function() {
                updateLicenseData();
            },

            /**
             * Determine if license includes "Research" feature.
             * @return {Boolean} True if feature set contains research.
             */
            isResearchView: function() {
                if (featureList.indexOf(RESEARCH_FEATURE) >= 0) {
                    return true;
                }
                return false;
            },

            /**
             * Determine if license includes the "Kinematics" feature.
             * @return {Boolean} True if feature set contains kinematics.
             */
            isKinematics: function() {
                if (featureList.indexOf(KINEMATICS_FEATURE) >= 0) {
                    return true;
                }
                return false;
            },

            /**
             * Determine if license includes "Clinic" feature.
             * @return {Boolean} True if feature set contains clinic.
             */
            isUpdateAvailable: function() {
                return updateAvailable;
            },

            updateApplication: function() {
                ServerHandler.getInstance().post(
                    {
                        type: ModelProtocol.update_application
                    },
                    null, null,
                    function(d) {
                        ErrorHandler.showError(d.error().statusText);
                    }
                );
            },

            /**
             * Destroy the current the instance, and don't reinitialize.
             */
            destroy: function() {
                instance = null;
            }
        };
    }

    return {
        getInstance: function() {
            if (!instance) {
                instance = init();
            }
            return instance;
        }
    };
});
