/* Copyright (c) 2014-2017 APDM, Inc.
 *
 * subject_table.js
 *
 */

define(['jquery', 'd3', 'utils', 'app/user_options_handler',
        'crossroads'],
       function ($, d3, utils, UserOptionsHandler, crossroads)
{
    'use strict';

    var cols = [];

    function tbl(selection) {
        cols = [
            {name: 'Subject ID', format: null},
            {name: 'Last name', format: null},
            {name: 'First name', format: null},
            {name: 'Date of birth', format: getBirthdateFormat()},
            {name: 'First visit', format: 'YYYY-MM-DD'},
            {name: 'Last visit', format: 'YYYY-MM-DD'},
            {name: '# of visits', format: null}
        ];

        selection.each( function(subjects) {
            var tableDiv = selection.selectAll('div').data([subjects]);
            var tableEnter = tableDiv.enter()
                .append('table');
            tableEnter.append('thead').attr('class', 'reports_head_row');
            tableEnter.append('tbody');

            // Update the table if needed
            tableEnter = selection.select('table')
                .attr('class', 'tablesorter table table-hover sortable')
                .attr('id', 'subjects-table');

            var thead = tableEnter.selectAll('thead');
            var theadRows = thead.selectAll('tr')
                .data([cols])
                .enter()
                .append('tr');
            theadRows.selectAll('th')
                .data(function(d) {
                    return d; })
                .enter()
                .append('th')
                .text(function(d) {
                    return d.name; });

            var tbody = tableEnter.selectAll('tbody');
            var rows = tbody.selectAll('tr')
                .data(subjects, function(d) { return d.getPublicId(); });
            var rowsEnter = rows.enter().append('tr')
                .on('click', function(d) {
                    var objId = d.getObjId();
                    crossroads.parse('dispatch/subject?id=' + objId.getId() +
                                     '&localId=' + objId.getLocalId());
                });
            rowsEnter.selectAll('td')
                .data(function(d) { return buildSubjectsTableEntry(d); })
                .enter()
                .append('td')
                .attr('class', 'selectable-row-cell')
                .attr('data-dateformat', function(d, i) { return cols[i].format; })
                .text(function(d) { return d; });

            rows.exit().remove();

            thead.select('th').attr('data-defaultsort', 'asc');
            $.bootstrapSortable(false);
        });
    }

    /**
     * Build the table entry for the given subject.
     * @param curSubject The Subject to create the entry for.
     * @return The table entry for the subject.
     */
    function buildSubjectsTableEntry(curSubject) {
        var entry = [];

        var displayed = UserOptionsHandler.getInstance()
            .getPatientRequiredFields();
        // Add the public id
        if (displayed.id === true) {
            entry.push(curSubject.getPublicId());
        } else {
            entry.push('--');
        }
        // Add the name
        if (displayed.name === true) {
            entry.push(curSubject.getLastName());
            entry.push(curSubject.getFirstName());
        } else {
            entry = entry.concat(['--', '--']);
        }

        // Build the string to display for birthday
        var dobStr = '';
        var dobObj = curSubject.getDateOfBirthObj();
        if (dobObj !== null && dobObj.isValid()) {
            if (displayed.birthYear === true) {
                if (displayed.birthMonth === true ||
                    displayed.birthDay === true) {
                    dobStr = dobObj.year() + '-';
                } else {
                    dobStr = dobObj.year();
                }
            }
            if (displayed.birthMonth === true) {
                var month = dobObj.month() + 1;
                if (month < 10) {
                    month = '0' + month;
                }
                if (displayed.birthDay === true) {
                    dobStr = dobStr + month + '-';
                } else {
                    dobStr = dobStr + month;
                }
            }
            if (displayed.birthDay === true) {
                var day = dobObj.date();
                if (day < 10) {
                    day = '0' + day;
                }
                dobStr = dobStr + day;
            }
        } else {
            dobStr = '--';
        }
        entry.push(dobStr);

        // Add some information about visits
        if (curSubject.getFirstVisit() && curSubject.getLastVisit()) {
            entry.push(utils.getMthDayYearFromDate(curSubject.getFirstVisit()));
            entry.push(utils.getMthDayYearFromDate(curSubject.getLastVisit()));
        } else {
            entry = entry.concat(['--', '--']);
        }
        entry.push(curSubject.getNumVisits());
        return entry;
    }

    /**
     * Get the format of the birthdate for proper sorting.
     * @return {String} Format string.
     */
    function getBirthdateFormat() {
        var displayed = UserOptionsHandler.getInstance()
            .getPatientRequiredFields();
        var format = '';
        if (displayed.birthYear === true) {
            if (displayed.birthMonth === true ||
                displayed.birthDay === true) {
                format = 'YYYY-';
            } else {
                format = 'YYYY';
            }
        }
        if (displayed.birthMonth === true) {
            if (displayed.birthDay === true) {
                format = format + 'MM-';
            } else {
                format = format + 'MM';
            }
        }
        if (displayed.birthDay === true) {
            format = format + 'DD';
        }
        return format;
    }

    return tbl;
});
