/* Copyright (c) 2017 APDM, Inc.
 *
 * user_timeout.js
 *
 */

/**
 * Singleton class to handle loging out a MX user after a given
 * timeout. Timeout will be set through a propertly retrieved from the
 * Mobility Exchange handler.
 */
define(['jquery', 'app/exchange_handler'],
       function($, ExchangeHandler)
{
    'use strict';

    var _instance;

    var _lastUserActivityTime = 0;
    var _bypassTimeout;

    function init() {

        _bypassTimeout = false;
        createUserLoginTimeout();

        return {

            /**
             * Set the flag that will allow bypassing the timeout. If
             * set to true, then the user will not be logged out if a
             * timeout occurs.
             * @param {Boolean} bypass Set to true if timeout should be
             *  bypassed.
             */
            bypassTimeout: function(bypass) {
                _bypassTimeout = bypass;
            }
        };
    }

    /**
     * Create handlers for user input events, and timer to check
     * when the last event occured. If over the user login timeout
     * limit, then log the user out of Mobility Exchange.
     */
    function createUserLoginTimeout() {
        var timeout = ExchangeHandler.getInstance().getUserTimeout();
        if (timeout === 0) {
            return;
        }

        _lastUserActivityTime = (new Date()).getTime();

        ['mousemove.userTimeout', 'mousedown.userTimeout', 'keydown.userTimeout']
            .forEach(function(d) {
                $(window).off(d);
                $(window).on(d, function() {
                    _lastUserActivityTime = (new Date()).getTime();
                });
            });

        setInterval(checkForTimeout, 1000);

        function checkForTimeout() {
            var currTime = (new Date()).getTime();
            if ((currTime - _lastUserActivityTime) / 1000 > timeout &&
                !_bypassTimeout) {
                ExchangeHandler.getInstance().userTimeoutLogout();
            }
        }
    }

    return {
        getInstance: function() {
            if(!_instance) {
                _instance = init();
            }
            return _instance;
        }
    };
});
